# This file is generated automatically by `build_database.py`. Change it there.
from sqf.expressions import BinaryExpression, UnaryExpression, NullExpression
from sqf.types import Keyword, Type, Nothing, Anything, String, Code, Array, Number, Boolean, Namespace, \
    Object, Config, Script, Control, Group, Display, Side, Task, Location, NetObject, DiaryReport, TeamMember
from sqf.interpreter_types import WhileType, \
    ForType, SwitchType, IfType, TryType, WithType


EXPRESSIONS = [
    BinaryExpression(Number, Keyword('!='), Number, Boolean),
    BinaryExpression(String, Keyword('!='), String, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(Group, Keyword('!='), Group, Boolean),
    BinaryExpression(Side, Keyword('!='), Side, Boolean),
    BinaryExpression(String, Keyword('!='), String, Boolean),
    BinaryExpression(Config, Keyword('!='), Config, Boolean),
    BinaryExpression(Display, Keyword('!='), Display, Boolean),
    BinaryExpression(Control, Keyword('!='), Control, Boolean),
    BinaryExpression(TeamMember, Keyword('!='), TeamMember, Boolean),
    BinaryExpression(NetObject, Keyword('!='), NetObject, Boolean),
    BinaryExpression(Task, Keyword('!='), Task, Boolean),
    BinaryExpression(Location, Keyword('!='), Location, Boolean),
    BinaryExpression(Number, Keyword('%'), Number, Number),
    BinaryExpression(Boolean, Keyword('&&'), Boolean, Boolean),
    BinaryExpression(Boolean, Keyword('&&'), Code, Boolean),
    BinaryExpression(Number, Keyword('*'), Number, Number),
    BinaryExpression(Number, Keyword('+'), Number, Number),
    BinaryExpression(String, Keyword('+'), String, String),
    BinaryExpression(Array, Keyword('+'), Array, Array),
    BinaryExpression(Number, Keyword('-'), Number, Number),
    BinaryExpression(Array, Keyword('-'), Array, Array),
    BinaryExpression(Number, Keyword('/'), Number, Number),
    BinaryExpression(Config, Keyword('/'), String, Config),
    BinaryExpression(SwitchType, Keyword(':'), Code, Nothing),
    BinaryExpression(Number, Keyword('<'), Number, Boolean),
    BinaryExpression(Number, Keyword('<='), Number, Boolean),
    BinaryExpression(Number, Keyword('=='), Number, Boolean),
    BinaryExpression(String, Keyword('=='), String, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(Group, Keyword('=='), Group, Boolean),
    BinaryExpression(Side, Keyword('=='), Side, Boolean),
    BinaryExpression(String, Keyword('=='), String, Boolean),
    BinaryExpression(Config, Keyword('=='), Config, Boolean),
    BinaryExpression(Display, Keyword('=='), Display, Boolean),
    BinaryExpression(Control, Keyword('=='), Control, Boolean),
    BinaryExpression(TeamMember, Keyword('=='), TeamMember, Boolean),
    BinaryExpression(NetObject, Keyword('=='), NetObject, Boolean),
    BinaryExpression(Task, Keyword('=='), Task, Boolean),
    BinaryExpression(Location, Keyword('=='), Location, Boolean),
    BinaryExpression(Number, Keyword('>'), Number, Boolean),
    BinaryExpression(Number, Keyword('>='), Number, Boolean),
    BinaryExpression(Config, Keyword('>>'), String, Config),
    BinaryExpression(Number, Keyword('^'), Number, Number),
    BinaryExpression(Boolean, Keyword('||'), Boolean, Boolean),
    BinaryExpression(Boolean, Keyword('||'), Code, Boolean),
    UnaryExpression(Keyword('!'), Boolean, Boolean),
    UnaryExpression(Keyword('+'), Number, Number),
    UnaryExpression(Keyword('+'), Array, Array),
    UnaryExpression(Keyword('-'), Number, Number),
    UnaryExpression(Keyword('abs'), Number, Number),
    UnaryExpression(Keyword('acos'), Number, Number),
    UnaryExpression(Keyword('actionids'), Object, Array),
    UnaryExpression(Keyword('actionkeys'), String, Array),
    UnaryExpression(Keyword('actionkeysimages'), String, String),
    UnaryExpression(Keyword('actionkeysimages'), Array, String),
    UnaryExpression(Keyword('actionkeysnames'), String, String),
    UnaryExpression(Keyword('actionkeysnames'), Array, String),
    UnaryExpression(Keyword('actionkeysnamesarray'), String, Array),
    UnaryExpression(Keyword('actionkeysnamesarray'), Array, Array),
    UnaryExpression(Keyword('actionname'), String, String),
    UnaryExpression(Keyword('activateaddons'), Array, Nothing),
    UnaryExpression(Keyword('activatekey'), String, Nothing),
    UnaryExpression(Keyword('add3denconnection'), Array, Nothing),
    UnaryExpression(Keyword('add3deneventhandler'), Array, Number),
    UnaryExpression(Keyword('addcamshake'), Array, Nothing),
    UnaryExpression(Keyword('addforcegeneratorrtd'), Array, Number),
    UnaryExpression(Keyword('additempool'), Array, Nothing),
    UnaryExpression(Keyword('addmagazinepool'), Array, Nothing),
    UnaryExpression(Keyword('addmissioneventhandler'), Array, Number),
    UnaryExpression(Keyword('addmusiceventhandler'), Array, Number),
    UnaryExpression(Keyword('addswitchableunit'), Object, Nothing),
    UnaryExpression(Keyword('addtoremainscollector'), Array, Nothing),
    UnaryExpression(Keyword('addweaponpool'), Array, Nothing),
    UnaryExpression(Keyword('admin'), Number, Number),
    UnaryExpression(Keyword('agent'), TeamMember, Object),
    UnaryExpression(Keyword('agltoasl'), Array, Array),
    UnaryExpression(Keyword('aimpos'), Object, Array),
    UnaryExpression(Keyword('airdensityrtd'), Number, Number),
    UnaryExpression(Keyword('airplanethrottle'), Object, Number),
    UnaryExpression(Keyword('airportside'), Object, Nothing),
    UnaryExpression(Keyword('airportside'), Number, Nothing),
    UnaryExpression(Keyword('aisfinishheal'), Array, Nothing),
    UnaryExpression(Keyword('alive'), Object, Boolean),
    UnaryExpression(Keyword('allcontrols'), Display, Array),
    UnaryExpression(Keyword('allmissionobjects'), String, Array),
    UnaryExpression(Keyword('allsimpleobjects'), Array, Array),
    UnaryExpression(Keyword('allturrets'), Array, Array),
    UnaryExpression(Keyword('allturrets'), Object, Array),
    UnaryExpression(Keyword('allvariables'), Control, Array),
    UnaryExpression(Keyword('allvariables'), TeamMember, Array),
    UnaryExpression(Keyword('allvariables'), Namespace, Array),
    UnaryExpression(Keyword('allvariables'), Object, Array),
    UnaryExpression(Keyword('allvariables'), Group, Array),
    UnaryExpression(Keyword('allvariables'), Task, Array),
    UnaryExpression(Keyword('allvariables'), Location, Array),
    UnaryExpression(Keyword('animationnames'), Object, Array),
    UnaryExpression(Keyword('animationstate'), Object, String),
    UnaryExpression(Keyword('asin'), Number, Number),
    UnaryExpression(Keyword('asltoagl'), Array, Array),
    UnaryExpression(Keyword('asltoatl'), Array, Array),
    UnaryExpression(Keyword('assert'), Boolean, Boolean),
    UnaryExpression(Keyword('assignedcargo'), Object, Array),
    UnaryExpression(Keyword('assignedcommander'), Object, Object),
    UnaryExpression(Keyword('assigneddriver'), Object, Object),
    UnaryExpression(Keyword('assignedgunner'), Object, Object),
    UnaryExpression(Keyword('assigneditems'), Object, Array),
    UnaryExpression(Keyword('assignedtarget'), Object, Object),
    UnaryExpression(Keyword('assignedteam'), Object, String),
    UnaryExpression(Keyword('assignedvehicle'), Object, Object),
    UnaryExpression(Keyword('assignedvehiclerole'), Object, Array),
    UnaryExpression(Keyword('atan'), Number, Number),
    UnaryExpression(Keyword('atg'), Number, Number),
    UnaryExpression(Keyword('atltoasl'), Array, Array),
    UnaryExpression(Keyword('attachedobject'), Location, Object),
    UnaryExpression(Keyword('attachedobjects'), Object, Array),
    UnaryExpression(Keyword('attachedto'), Object, Object),
    UnaryExpression(Keyword('attackenabled'), Object, Boolean),
    UnaryExpression(Keyword('attackenabled'), Group, Boolean),
    UnaryExpression(Keyword('backpack'), Object, String),
    UnaryExpression(Keyword('backpackcargo'), Object, Array),
    UnaryExpression(Keyword('backpackcontainer'), Object, Object),
    UnaryExpression(Keyword('backpackitems'), Object, Array),
    UnaryExpression(Keyword('backpackmagazines'), Object, Array),
    UnaryExpression(Keyword('behaviour'), Object, String),
    UnaryExpression(Keyword('binocular'), Object, String),
    UnaryExpression(Keyword('boundingbox'), Object, Array),
    UnaryExpression(Keyword('boundingboxreal'), Object, Array),
    UnaryExpression(Keyword('boundingcenter'), Object, Array),
    UnaryExpression(Keyword('breakout'), String, Nothing),
    UnaryExpression(Keyword('breakto'), String, Nothing),
    UnaryExpression(Keyword('buldozer_enableroaddiag'), Boolean, Nothing),
    UnaryExpression(Keyword('buldozer_loadnewroads'), String, Boolean),
    UnaryExpression(Keyword('buttonaction'), Control, String),
    UnaryExpression(Keyword('buttonaction'), Number, String),
    UnaryExpression(Keyword('buttonsetaction'), Array, Nothing),
    UnaryExpression(Keyword('call'), Code, Anything),
    UnaryExpression(Keyword('camcommitted'), Object, Boolean),
    UnaryExpression(Keyword('camdestroy'), Object, Nothing),
    UnaryExpression(Keyword('cameraeffectenablehud'), Boolean, Nothing),
    UnaryExpression(Keyword('camerainterest'), Object, Number),
    UnaryExpression(Keyword('campreloaded'), Object, Boolean),
    UnaryExpression(Keyword('camtarget'), Object, Object),
    UnaryExpression(Keyword('camusenvg'), Boolean, Nothing),
    UnaryExpression(Keyword('cancelsimpletaskdestination'), Task, Nothing),
    UnaryExpression(Keyword('canfire'), Object, Boolean),
    UnaryExpression(Keyword('canmove'), Object, Boolean),
    UnaryExpression(Keyword('canstand'), Object, Boolean),
    UnaryExpression(Keyword('cantriggerdynamicsimulation'), Object, Boolean),
    UnaryExpression(Keyword('canunloadincombat'), Object, Boolean),
    UnaryExpression(Keyword('captive'), Object, Boolean),
    UnaryExpression(Keyword('captivenum'), Object, Number),
    UnaryExpression(Keyword('case'), Type, SwitchType),
    UnaryExpression(Keyword('cbchecked'), Control, Boolean),
    UnaryExpression(Keyword('ceil'), Number, Number),
    UnaryExpression(Keyword('channelenabled'), Number, Array),
    UnaryExpression(Keyword('checkaifeature'), String, Boolean),
    UnaryExpression(Keyword('classname'), Location, String),
    UnaryExpression(Keyword('clear3deninventory'), Array, Nothing),
    UnaryExpression(Keyword('clearallitemsfrombackpack'), Object, Nothing),
    UnaryExpression(Keyword('clearbackpackcargo'), Object, Nothing),
    UnaryExpression(Keyword('clearbackpackcargoglobal'), Object, Nothing),
    UnaryExpression(Keyword('cleargroupicons'), Group, Nothing),
    UnaryExpression(Keyword('clearitemcargo'), Object, Nothing),
    UnaryExpression(Keyword('clearitemcargoglobal'), Object, Nothing),
    UnaryExpression(Keyword('clearmagazinecargo'), Object, Nothing),
    UnaryExpression(Keyword('clearmagazinecargoglobal'), Object, Nothing),
    UnaryExpression(Keyword('clearoverlay'), Control, Nothing),
    UnaryExpression(Keyword('clearweaponcargo'), Object, Nothing),
    UnaryExpression(Keyword('clearweaponcargoglobal'), Object, Nothing),
    UnaryExpression(Keyword('closedialog'), Number, Nothing),
    UnaryExpression(Keyword('closeoverlay'), Control, Nothing),
    UnaryExpression(Keyword('collapseobjecttree'), Control, Nothing),
    UnaryExpression(Keyword('collect3denhistory'), Code, Nothing),
    UnaryExpression(Keyword('collectivertd'), Object, Number),
    UnaryExpression(Keyword('combatmode'), Object, String),
    UnaryExpression(Keyword('combatmode'), Group, String),
    UnaryExpression(Keyword('commander'), Object, Object),
    UnaryExpression(Keyword('commandgetout'), Object, Nothing),
    UnaryExpression(Keyword('commandgetout'), Array, Nothing),
    UnaryExpression(Keyword('commandstop'), Object, Nothing),
    UnaryExpression(Keyword('commandstop'), Array, Nothing),
    UnaryExpression(Keyword('comment'), String, Nothing),
    UnaryExpression(Keyword('commitoverlay'), Control, Nothing),
    UnaryExpression(Keyword('compile'), String, Code),
    UnaryExpression(Keyword('compilefinal'), String, Code),
    UnaryExpression(Keyword('completedfsm'), Number, Boolean),
    UnaryExpression(Keyword('composetext'), Array, String),
    UnaryExpression(Keyword('confighierarchy'), Config, Array),
    UnaryExpression(Keyword('configname'), Config, String),
    UnaryExpression(Keyword('configproperties'), Array, Array),
    UnaryExpression(Keyword('configsourceaddonlist'), Config, Array),
    UnaryExpression(Keyword('configsourcemod'), Config, String),
    UnaryExpression(Keyword('configsourcemodlist'), Config, Array),
    UnaryExpression(Keyword('copytoclipboard'), String, Nothing),
    UnaryExpression(Keyword('cos'), Number, Number),
    UnaryExpression(Keyword('count'), Array, Number),
    UnaryExpression(Keyword('count'), String, Number),
    UnaryExpression(Keyword('count'), Config, Number),
    UnaryExpression(Keyword('create3dencomposition'), Array, Array),
    UnaryExpression(Keyword('create3denentity'), Array, Anything),
    UnaryExpression(Keyword('createagent'), Array, Object),
    UnaryExpression(Keyword('createcenter'), Side, Side),
    UnaryExpression(Keyword('createdialog'), String, Boolean),
    UnaryExpression(Keyword('creatediarylink'), Array, String),
    UnaryExpression(Keyword('creategeardialog'), Array, Nothing),
    UnaryExpression(Keyword('creategroup'), Side, Group),
    UnaryExpression(Keyword('creategroup'), Array, Group),
    UnaryExpression(Keyword('createguardedpoint'), Array, Nothing),
    UnaryExpression(Keyword('createlocation'), Array, Location),
    UnaryExpression(Keyword('createmarker'), Array, String),
    UnaryExpression(Keyword('createmarkerlocal'), Array, String),
    UnaryExpression(Keyword('createmine'), Array, Object),
    UnaryExpression(Keyword('createsimpleobject'), Array, Object),
    UnaryExpression(Keyword('createsoundsource'), Array, Object),
    UnaryExpression(Keyword('createteam'), Array, TeamMember),
    UnaryExpression(Keyword('createtrigger'), Array, Object),
    UnaryExpression(Keyword('createvehicle'), Array, Object),
    UnaryExpression(Keyword('createvehiclecrew'), Object, Nothing),
    UnaryExpression(Keyword('crew'), Object, Array),
    UnaryExpression(Keyword('ctaddheader'), Control, Array),
    UnaryExpression(Keyword('ctaddrow'), Control, Array),
    UnaryExpression(Keyword('ctclear'), Control, Nothing),
    UnaryExpression(Keyword('ctcursel'), Control, Number),
    UnaryExpression(Keyword('ctheadercount'), Control, Number),
    UnaryExpression(Keyword('ctrlactivate'), Control, Nothing),
    UnaryExpression(Keyword('ctrlangle'), Control, Array),
    UnaryExpression(Keyword('ctrlautoscrolldelay'), Control, Number),
    UnaryExpression(Keyword('ctrlautoscrollrewind'), Control, Boolean),
    UnaryExpression(Keyword('ctrlautoscrollspeed'), Control, Number),
    UnaryExpression(Keyword('ctrlchecked'), Control, Boolean),
    UnaryExpression(Keyword('ctrlclassname'), Control, String),
    UnaryExpression(Keyword('ctrlcommitted'), Control, Boolean),
    UnaryExpression(Keyword('ctrldelete'), Control, Boolean),
    UnaryExpression(Keyword('ctrlenable'), Array, Nothing),
    UnaryExpression(Keyword('ctrlenabled'), Control, Boolean),
    UnaryExpression(Keyword('ctrlenabled'), Number, Boolean),
    UnaryExpression(Keyword('ctrlfade'), Control, Number),
    UnaryExpression(Keyword('ctrlhtmlloaded'), Control, Boolean),
    UnaryExpression(Keyword('ctrlidc'), Control, Number),
    UnaryExpression(Keyword('ctrlidd'), Display, Number),
    UnaryExpression(Keyword('ctrlmapanimclear'), Control, Nothing),
    UnaryExpression(Keyword('ctrlmapanimcommit'), Control, Nothing),
    UnaryExpression(Keyword('ctrlmapanimdone'), Control, Boolean),
    UnaryExpression(Keyword('ctrlmapmouseover'), Control, Array),
    UnaryExpression(Keyword('ctrlmapscale'), Control, Number),
    UnaryExpression(Keyword('ctrlmodel'), Control, String),
    UnaryExpression(Keyword('ctrlmodeldirandup'), Control, Array),
    UnaryExpression(Keyword('ctrlmodelscale'), Control, Number),
    UnaryExpression(Keyword('ctrlparent'), Control, Display),
    UnaryExpression(Keyword('ctrlparentcontrolsgroup'), Control, Control),
    UnaryExpression(Keyword('ctrlposition'), Control, Array),
    UnaryExpression(Keyword('ctrlscale'), Control, Number),
    UnaryExpression(Keyword('ctrlsetfocus'), Control, Nothing),
    UnaryExpression(Keyword('ctrlsettext'), Array, Nothing),
    UnaryExpression(Keyword('ctrlshow'), Array, Nothing),
    UnaryExpression(Keyword('ctrlshown'), Control, Boolean),
    UnaryExpression(Keyword('ctrltext'), Control, String),
    UnaryExpression(Keyword('ctrltext'), Number, String),
    UnaryExpression(Keyword('ctrltextheight'), Control, Number),
    UnaryExpression(Keyword('ctrltextsecondary'), Control, String),
    UnaryExpression(Keyword('ctrltype'), Control, Number),
    UnaryExpression(Keyword('ctrlvisible'), Number, Boolean),
    UnaryExpression(Keyword('ctrowcount'), Control, Number),
    UnaryExpression(Keyword('curatoraddons'), Object, Array),
    UnaryExpression(Keyword('curatorcameraarea'), Object, Array),
    UnaryExpression(Keyword('curatorcameraareaceiling'), Object, Number),
    UnaryExpression(Keyword('curatoreditableobjects'), Object, Array),
    UnaryExpression(Keyword('curatoreditingarea'), Object, Array),
    UnaryExpression(Keyword('curatoreditingareatype'), Object, Boolean),
    UnaryExpression(Keyword('curatorpoints'), Object, Number),
    UnaryExpression(Keyword('curatorregisteredobjects'), Object, Array),
    UnaryExpression(Keyword('curatorwaypointcost'), Object, Number),
    UnaryExpression(Keyword('currentcommand'), Object, String),
    UnaryExpression(Keyword('currentmagazine'), Object, String),
    UnaryExpression(Keyword('currentmagazinedetail'), Object, Array),
    UnaryExpression(Keyword('currentmuzzle'), Object, String),
    UnaryExpression(Keyword('currenttask'), Object, Task),
    UnaryExpression(Keyword('currenttasks'), TeamMember, Array),
    UnaryExpression(Keyword('currentthrowable'), Object, Array),
    UnaryExpression(Keyword('currentvisionmode'), Object, Number),
    UnaryExpression(Keyword('currentwaypoint'), Group, Number),
    UnaryExpression(Keyword('currentweapon'), Object, String),
    UnaryExpression(Keyword('currentweaponmode'), Object, String),
    UnaryExpression(Keyword('currentzeroing'), Object, Number),
    UnaryExpression(Keyword('cutobj'), Array, Nothing),
    UnaryExpression(Keyword('cutrsc'), Array, Nothing),
    UnaryExpression(Keyword('cuttext'), Array, Nothing),
    UnaryExpression(Keyword('damage'), Object, Number),
    UnaryExpression(Keyword('datetonumber'), Array, Number),
    UnaryExpression(Keyword('deactivatekey'), String, Nothing),
    UnaryExpression(Keyword('debriefingtext'), String, Number),
    UnaryExpression(Keyword('debuglog'), Type, Nothing),
    UnaryExpression(Keyword('default'), Code, Nothing),
    UnaryExpression(Keyword('deg'), Number, Number),
    UnaryExpression(Keyword('delete3denentities'), Array, Nothing),
    UnaryExpression(Keyword('deletecenter'), Side, Nothing),
    UnaryExpression(Keyword('deletecollection'), Object, Nothing),
    UnaryExpression(Keyword('deletegroup'), Group, Nothing),
    UnaryExpression(Keyword('deleteidentity'), String, Boolean),
    UnaryExpression(Keyword('deletelocation'), Location, Nothing),
    UnaryExpression(Keyword('deletemarker'), String, Nothing),
    UnaryExpression(Keyword('deletemarkerlocal'), String, Nothing),
    UnaryExpression(Keyword('deletesite'), Object, Nothing),
    UnaryExpression(Keyword('deletestatus'), String, Boolean),
    UnaryExpression(Keyword('deleteteam'), TeamMember, Nothing),
    UnaryExpression(Keyword('deletevehicle'), Object, Nothing),
    UnaryExpression(Keyword('deletewaypoint'), Array, Nothing),
    UnaryExpression(Keyword('detach'), Object, Nothing),
    UnaryExpression(Keyword('detectedmines'), Side, Array),
    UnaryExpression(Keyword('diag_captureframe'), Number, Nothing),
    UnaryExpression(Keyword('diag_captureframetofile'), Number, Nothing),
    UnaryExpression(Keyword('diag_captureslowframe'), Array, Nothing),
    UnaryExpression(Keyword('diag_codeperformance'), Array, Array),
    UnaryExpression(Keyword('diag_dynamicsimulationend'), String, Nothing),
    UnaryExpression(Keyword('diag_log'), Type, Nothing),
    UnaryExpression(Keyword('diag_logslowframe'), Array, Nothing),
    UnaryExpression(Keyword('didjipowner'), Object, Boolean),
    UnaryExpression(Keyword('difficultyenabled'), String, Boolean),
    UnaryExpression(Keyword('difficultyoption'), String, Number),
    UnaryExpression(Keyword('direction'), Object, Number),
    UnaryExpression(Keyword('direction'), Location, Number),
    UnaryExpression(Keyword('disableremotesensors'), Boolean, Nothing),
    UnaryExpression(Keyword('disableuserinput'), Boolean, Nothing),
    UnaryExpression(Keyword('displayparent'), Display, Display),
    UnaryExpression(Keyword('dissolveteam'), String, Nothing),
    UnaryExpression(Keyword('do3denaction'), String, Nothing),
    UnaryExpression(Keyword('dogetout'), Object, Nothing),
    UnaryExpression(Keyword('dogetout'), Array, Nothing),
    UnaryExpression(Keyword('dostop'), Object, Nothing),
    UnaryExpression(Keyword('dostop'), Array, Nothing),
    UnaryExpression(Keyword('drawicon3d'), Array, Nothing),
    UnaryExpression(Keyword('drawline3d'), Array, Nothing),
    UnaryExpression(Keyword('driver'), Object, Object),
    UnaryExpression(Keyword('drop'), Array, Nothing),
    UnaryExpression(Keyword('dynamicsimulationdistance'), String, Number),
    UnaryExpression(Keyword('dynamicsimulationdistancecoef'), String, Number),
    UnaryExpression(Keyword('dynamicsimulationenabled'), Object, Boolean),
    UnaryExpression(Keyword('dynamicsimulationenabled'), Group, Boolean),
    UnaryExpression(Keyword('echo'), String, Nothing),
    UnaryExpression(Keyword('edit3denmissionattributes'), String, Nothing),
    UnaryExpression(Keyword('effectivecommander'), Object, Object),
    UnaryExpression(Keyword('enableaudiofeature'), Array, Boolean),
    UnaryExpression(Keyword('enablecamshake'), Boolean, Nothing),
    UnaryExpression(Keyword('enablecaustics'), Boolean, Nothing),
    UnaryExpression(Keyword('enabledebriefingstats'), Array, Nothing),
    UnaryExpression(Keyword('enablediaglegend'), Boolean, Nothing),
    UnaryExpression(Keyword('enabledynamicsimulationsystem'), Boolean, Nothing),
    UnaryExpression(Keyword('enableengineartillery'), Boolean, Nothing),
    UnaryExpression(Keyword('enableenvironment'), Boolean, Nothing),
    UnaryExpression(Keyword('enableenvironment'), Array, Nothing),
    UnaryExpression(Keyword('enableradio'), Boolean, Nothing),
    UnaryExpression(Keyword('enablesatnormalondetail'), Boolean, Nothing),
    UnaryExpression(Keyword('enablesaving'), Boolean, Nothing),
    UnaryExpression(Keyword('enablesaving'), Array, Nothing),
    UnaryExpression(Keyword('enablesentences'), Boolean, Nothing),
    UnaryExpression(Keyword('enablestressdamage'), Boolean, Nothing),
    UnaryExpression(Keyword('enableteamswitch'), Boolean, Nothing),
    UnaryExpression(Keyword('enabletraffic'), Boolean, Nothing),
    UnaryExpression(Keyword('enableweapondisassembly'), Boolean, Nothing),
    UnaryExpression(Keyword('endmission'), String, Nothing),
    UnaryExpression(Keyword('enginesisonrtd'), Object, Array),
    UnaryExpression(Keyword('enginespowerrtd'), Object, Array),
    UnaryExpression(Keyword('enginesrpmrtd'), Object, Array),
    UnaryExpression(Keyword('enginestorquertd'), Object, Array),
    UnaryExpression(Keyword('entities'), String, Array),
    UnaryExpression(Keyword('entities'), Array, Array),
    UnaryExpression(Keyword('estimatedtimeleft'), Number, Nothing),
    UnaryExpression(Keyword('everybackpack'), Object, Array),
    UnaryExpression(Keyword('everycontainer'), Object, Array),
    UnaryExpression(Keyword('execfsm'), String, Number),
    UnaryExpression(Keyword('execvm'), String, Script),
    UnaryExpression(Keyword('exp'), Number, Number),
    UnaryExpression(Keyword('expecteddestination'), Object, Array),
    UnaryExpression(Keyword('exportjipmessages'), String, Nothing),
    UnaryExpression(Keyword('eyedirection'), Object, Array),
    UnaryExpression(Keyword('eyepos'), Object, Array),
    UnaryExpression(Keyword('face'), Object, String),
    UnaryExpression(Keyword('faction'), Object, String),
    UnaryExpression(Keyword('failmission'), String, Nothing),
    UnaryExpression(Keyword('fillweaponsfrompool'), Object, Nothing),
    UnaryExpression(Keyword('finddisplay'), Number, Display),
    UnaryExpression(Keyword('finite'), Number, Boolean),
    UnaryExpression(Keyword('firstbackpack'), Object, Object),
    UnaryExpression(Keyword('flag'), Object, Object),
    UnaryExpression(Keyword('flaganimationphase'), Object, Number),
    UnaryExpression(Keyword('flagowner'), Object, Object),
    UnaryExpression(Keyword('flagside'), Object, Side),
    UnaryExpression(Keyword('flagtexture'), Object, String),
    UnaryExpression(Keyword('fleeing'), Object, Boolean),
    UnaryExpression(Keyword('floor'), Number, Number),
    UnaryExpression(Keyword('for'), String, ForType),
    UnaryExpression(Keyword('for'), Array, ForType),
    UnaryExpression(Keyword('forceatpositionrtd'), Array, Array),
    UnaryExpression(Keyword('forcegeneratorrtd'), Number, Array),
    UnaryExpression(Keyword('forcemap'), Boolean, Nothing),
    UnaryExpression(Keyword('forcerespawn'), Object, Nothing),
    UnaryExpression(Keyword('format'), Array, String),
    UnaryExpression(Keyword('formation'), Object, String),
    UnaryExpression(Keyword('formation'), Group, String),
    UnaryExpression(Keyword('formation'), TeamMember, String),
    UnaryExpression(Keyword('formationdirection'), Object, Number),
    UnaryExpression(Keyword('formationleader'), Object, Object),
    UnaryExpression(Keyword('formationmembers'), Object, Array),
    UnaryExpression(Keyword('formationposition'), Object, Array),
    UnaryExpression(Keyword('formationtask'), Object, String),
    UnaryExpression(Keyword('formattext'), Array, String),
    UnaryExpression(Keyword('formleader'), Object, Object),
    UnaryExpression(Keyword('fromeditor'), TeamMember, Boolean),
    UnaryExpression(Keyword('fuel'), Object, Number),
    UnaryExpression(Keyword('fullcrew'), Object, Array),
    UnaryExpression(Keyword('fullcrew'), Array, Array),
    UnaryExpression(Keyword('gearidcammocount'), Number, Number),
    UnaryExpression(Keyword('gearslotammocount'), Control, Number),
    UnaryExpression(Keyword('gearslotdata'), Control, String),
    UnaryExpression(Keyword('get3denactionstate'), String, Number),
    UnaryExpression(Keyword('get3denconnections'), Type, Array),
    UnaryExpression(Keyword('get3denentity'), Number, Anything),
    UnaryExpression(Keyword('get3denentityid'), Type, Number),
    UnaryExpression(Keyword('get3dengrid'), String, Nothing),
    UnaryExpression(Keyword('get3denlayerentities'), Number, Array),
    UnaryExpression(Keyword('get3denselected'), String, Array),
    UnaryExpression(Keyword('getaimingcoef'), Object, Number),
    UnaryExpression(Keyword('getallenvsoundcontrollers'), Array, Array),
    UnaryExpression(Keyword('getallhitpointsdamage'), Object, Array),
    UnaryExpression(Keyword('getallownedmines'), Object, Array),
    UnaryExpression(Keyword('getallsoundcontrollers'), Object, Array),
    UnaryExpression(Keyword('getammocargo'), Object, Number),
    UnaryExpression(Keyword('getanimaimprecision'), Object, Number),
    UnaryExpression(Keyword('getanimspeedcoef'), Object, Number),
    UnaryExpression(Keyword('getarray'), Config, Array),
    UnaryExpression(Keyword('getartilleryammo'), Array, Array),
    UnaryExpression(Keyword('getassignedcuratorlogic'), Object, Object),
    UnaryExpression(Keyword('getassignedcuratorunit'), Object, Object),
    UnaryExpression(Keyword('getbackpackcargo'), Object, Array),
    UnaryExpression(Keyword('getbleedingremaining'), Object, Number),
    UnaryExpression(Keyword('getburningvalue'), Object, Number),
    UnaryExpression(Keyword('getcameraviewdirection'), Object, Array),
    UnaryExpression(Keyword('getcenterofmass'), Object, Array),
    UnaryExpression(Keyword('getconnecteduav'), Object, Object),
    UnaryExpression(Keyword('getcontainermaxload'), String, Number),
    UnaryExpression(Keyword('getcustomaimcoef'), Object, Number),
    UnaryExpression(Keyword('getdammage'), Object, Number),
    UnaryExpression(Keyword('getdescription'), Object, Array),
    UnaryExpression(Keyword('getdir'), Object, Number),
    UnaryExpression(Keyword('getdirvisual'), Object, Number),
    UnaryExpression(Keyword('getdlcassetsusagebyname'), String, Array),
    UnaryExpression(Keyword('getdlcs'), Number, Array),
    UnaryExpression(Keyword('getdlcusagetime'), Number, Number),
    UnaryExpression(Keyword('geteditorcamera'), Control, Object),
    UnaryExpression(Keyword('geteditormode'), Control, String),
    UnaryExpression(Keyword('getenginetargetrpmrtd'), Object, Array),
    UnaryExpression(Keyword('getfatigue'), Object, Number),
    UnaryExpression(Keyword('getfieldmanualstartpage'), Display, Array),
    UnaryExpression(Keyword('getforcedflagtexture'), Object, String),
    UnaryExpression(Keyword('getfuelcargo'), Object, Number),
    UnaryExpression(Keyword('getgroupiconparams'), Group, Array),
    UnaryExpression(Keyword('getgroupicons'), Group, Array),
    UnaryExpression(Keyword('getitemcargo'), Object, Array),
    UnaryExpression(Keyword('getmagazinecargo'), Object, Array),
    UnaryExpression(Keyword('getmarkercolor'), String, String),
    UnaryExpression(Keyword('getmarkerpos'), String, Array),
    UnaryExpression(Keyword('getmarkersize'), String, Array),
    UnaryExpression(Keyword('getmarkertype'), String, String),
    UnaryExpression(Keyword('getmass'), Object, Number),
    UnaryExpression(Keyword('getmissionconfig'), String, Config),
    UnaryExpression(Keyword('getmissionconfigvalue'), String, Anything),
    UnaryExpression(Keyword('getmissionconfigvalue'), Array, Anything),
    UnaryExpression(Keyword('getmissionlayerentities'), String, Array),
    UnaryExpression(Keyword('getmissionlayerentities'), Number, Array),
    UnaryExpression(Keyword('getmodelinfo'), Object, Array),
    UnaryExpression(Keyword('getnumber'), Config, Number),
    UnaryExpression(Keyword('getobjectdlc'), Object, Number),
    UnaryExpression(Keyword('getobjectmaterials'), Object, Array),
    UnaryExpression(Keyword('getobjecttextures'), Object, Array),
    UnaryExpression(Keyword('getobjecttype'), Object, Number),
    UnaryExpression(Keyword('getoxygenremaining'), Object, Number),
    UnaryExpression(Keyword('getpersonuseddlcs'), Object, Array),
    UnaryExpression(Keyword('getpilotcameradirection'), Object, Array),
    UnaryExpression(Keyword('getpilotcameraposition'), Object, Array),
    UnaryExpression(Keyword('getpilotcamerarotation'), Object, Array),
    UnaryExpression(Keyword('getpilotcameratarget'), Object, Array),
    UnaryExpression(Keyword('getplayerchannel'), Object, Number),
    UnaryExpression(Keyword('getplayerscores'), Object, Array),
    UnaryExpression(Keyword('getplayeruid'), Object, String),
    UnaryExpression(Keyword('getpos'), Object, Array),
    UnaryExpression(Keyword('getpos'), Location, Array),
    UnaryExpression(Keyword('getposasl'), Object, Array),
    UnaryExpression(Keyword('getposaslvisual'), Object, Array),
    UnaryExpression(Keyword('getposaslw'), Object, Array),
    UnaryExpression(Keyword('getposatl'), Object, Array),
    UnaryExpression(Keyword('getposatlvisual'), Object, Array),
    UnaryExpression(Keyword('getposvisual'), Object, Array),
    UnaryExpression(Keyword('getposworld'), Object, Array),
    UnaryExpression(Keyword('getpylonmagazines'), Object, Array),
    UnaryExpression(Keyword('getrepaircargo'), Object, Number),
    UnaryExpression(Keyword('getrotorbrakertd'), Object, Number),
    UnaryExpression(Keyword('getshotparents'), Object, Array),
    UnaryExpression(Keyword('getslingload'), Object, Object),
    UnaryExpression(Keyword('getstamina'), Object, Number),
    UnaryExpression(Keyword('getstatvalue'), String, Number),
    UnaryExpression(Keyword('getsuppression'), Object, Number),
    UnaryExpression(Keyword('getterrainheightasl'), Array, Number),
    UnaryExpression(Keyword('gettext'), Config, String),
    UnaryExpression(Keyword('gettrimoffsetrtd'), Object, Array),
    UnaryExpression(Keyword('getunitloadout'), Object, Array),
    UnaryExpression(Keyword('getunitloadout'), Array, Array),
    UnaryExpression(Keyword('getunitloadout'), String, Array),
    UnaryExpression(Keyword('getunitloadout'), Config, Array),
    UnaryExpression(Keyword('getusermfdvalue'), Object, Array),
    UnaryExpression(Keyword('getvehiclecargo'), Object, Array),
    UnaryExpression(Keyword('getweaponcargo'), Object, Array),
    UnaryExpression(Keyword('getweaponsway'), Object, Number),
    UnaryExpression(Keyword('getwingsorientationrtd'), Object, Number),
    UnaryExpression(Keyword('getwingspositionrtd'), Object, Number),
    UnaryExpression(Keyword('getwppos'), Array, Array),
    UnaryExpression(Keyword('goggles'), Object, String),
    UnaryExpression(Keyword('goto'), String, Nothing),
    UnaryExpression(Keyword('group'), Object, Group),
    UnaryExpression(Keyword('groupfromnetid'), String, Group),
    UnaryExpression(Keyword('groupid'), Group, String),
    UnaryExpression(Keyword('groupowner'), Group, Number),
    UnaryExpression(Keyword('groupselectedunits'), Object, Array),
    UnaryExpression(Keyword('gunner'), Object, Object),
    UnaryExpression(Keyword('handgunitems'), Object, Array),
    UnaryExpression(Keyword('handgunmagazine'), Object, Array),
    UnaryExpression(Keyword('handgunweapon'), Object, String),
    UnaryExpression(Keyword('handshit'), Object, Number),
    UnaryExpression(Keyword('haspilotcamera'), Object, Boolean),
    UnaryExpression(Keyword('hcallgroups'), Object, Array),
    UnaryExpression(Keyword('hcleader'), Group, Object),
    UnaryExpression(Keyword('hcremoveallgroups'), Object, Nothing),
    UnaryExpression(Keyword('hcselected'), Object, Array),
    UnaryExpression(Keyword('hcshowbar'), Boolean, Nothing),
    UnaryExpression(Keyword('headgear'), Object, String),
    UnaryExpression(Keyword('hidebody'), Object, Nothing),
    UnaryExpression(Keyword('hideobject'), Object, Nothing),
    UnaryExpression(Keyword('hideobjectglobal'), Object, Nothing),
    UnaryExpression(Keyword('hint'), String, Nothing),
    UnaryExpression(Keyword('hint'), String, Nothing),
    UnaryExpression(Keyword('hintc'), String, Nothing),
    UnaryExpression(Keyword('hintcadet'), String, Nothing),
    UnaryExpression(Keyword('hintcadet'), String, Nothing),
    UnaryExpression(Keyword('hintsilent'), String, Nothing),
    UnaryExpression(Keyword('hintsilent'), String, Nothing),
    UnaryExpression(Keyword('hmd'), Object, String),
    UnaryExpression(Keyword('hostmission'), Array, Nothing),
    UnaryExpression(Keyword('if'), Boolean, IfType),
    UnaryExpression(Keyword('image'), String, String),
    UnaryExpression(Keyword('importallgroups'), Control, Nothing),
    UnaryExpression(Keyword('importance'), Location, Number),
    UnaryExpression(Keyword('incapacitatedstate'), Object, String),
    UnaryExpression(Keyword('inflamed'), Object, Boolean),
    UnaryExpression(Keyword('infopanel'), String, Array),
    UnaryExpression(Keyword('infopanels'), Object, Array),
    UnaryExpression(Keyword('infopanels'), Array, Array),
    UnaryExpression(Keyword('ingameuiseteventhandler'), Array, Nothing),
    UnaryExpression(Keyword('inheritsfrom'), Config, Config),
    UnaryExpression(Keyword('inputaction'), String, Number),
    UnaryExpression(Keyword('isabletobreathe'), Object, Boolean),
    UnaryExpression(Keyword('isagent'), TeamMember, Boolean),
    UnaryExpression(Keyword('isaimprecisionenabled'), Object, Boolean),
    UnaryExpression(Keyword('isarray'), Config, Boolean),
    UnaryExpression(Keyword('isautohoveron'), Object, Boolean),
    UnaryExpression(Keyword('isautonomous'), Object, Boolean),
    UnaryExpression(Keyword('isautostartupenabledrtd'), Object, Array),
    UnaryExpression(Keyword('isautotrimonrtd'), Object, Boolean),
    UnaryExpression(Keyword('isbleeding'), Object, Boolean),
    UnaryExpression(Keyword('isburning'), Object, Boolean),
    UnaryExpression(Keyword('isclass'), Config, Boolean),
    UnaryExpression(Keyword('iscollisionlighton'), Object, Boolean),
    UnaryExpression(Keyword('iscopilotenabled'), Object, Boolean),
    UnaryExpression(Keyword('isdamageallowed'), Object, Boolean),
    UnaryExpression(Keyword('isdlcavailable'), Number, Boolean),
    UnaryExpression(Keyword('isengineon'), Object, Boolean),
    UnaryExpression(Keyword('isforcedwalk'), Object, Boolean),
    UnaryExpression(Keyword('isformationleader'), Object, Boolean),
    UnaryExpression(Keyword('isgroupdeletedwhenempty'), Group, Boolean),
    UnaryExpression(Keyword('ishidden'), Object, Boolean),
    UnaryExpression(Keyword('isinremainscollector'), Object, Boolean),
    UnaryExpression(Keyword('iskeyactive'), String, Boolean),
    UnaryExpression(Keyword('islighton'), Object, Boolean),
    UnaryExpression(Keyword('islocalized'), String, Boolean),
    UnaryExpression(Keyword('ismanualfire'), Object, Boolean),
    UnaryExpression(Keyword('ismarkedforcollection'), Object, Boolean),
    UnaryExpression(Keyword('isnil'), Code, Boolean),
    UnaryExpression(Keyword('isnil'), String, Boolean),
    UnaryExpression(Keyword('isnull'), Object, Boolean),
    UnaryExpression(Keyword('isnull'), Group, Boolean),
    UnaryExpression(Keyword('isnull'), Script, Boolean),
    UnaryExpression(Keyword('isnull'), Config, Boolean),
    UnaryExpression(Keyword('isnull'), Display, Boolean),
    UnaryExpression(Keyword('isnull'), Control, Boolean),
    UnaryExpression(Keyword('isnull'), NetObject, Boolean),
    UnaryExpression(Keyword('isnull'), Task, Boolean),
    UnaryExpression(Keyword('isnull'), Location, Boolean),
    UnaryExpression(Keyword('isnumber'), Config, Boolean),
    UnaryExpression(Keyword('isobjecthidden'), Object, Boolean),
    UnaryExpression(Keyword('isobjectrtd'), Object, Boolean),
    UnaryExpression(Keyword('isonroad'), Object, Boolean),
    UnaryExpression(Keyword('isonroad'), Array, Boolean),
    UnaryExpression(Keyword('isplayer'), Object, Boolean),
    UnaryExpression(Keyword('isrealtime'), Control, Boolean),
    UnaryExpression(Keyword('isshowing3dicons'), Control, Boolean),
    UnaryExpression(Keyword('issimpleobject'), Object, Boolean),
    UnaryExpression(Keyword('issprintallowed'), Object, Boolean),
    UnaryExpression(Keyword('isstaminaenabled'), Object, Boolean),
    UnaryExpression(Keyword('istext'), Config, Boolean),
    UnaryExpression(Keyword('istouchingground'), Object, Boolean),
    UnaryExpression(Keyword('isturnedout'), Object, Boolean),
    UnaryExpression(Keyword('isuavconnected'), Object, Boolean),
    UnaryExpression(Keyword('isvehiclecargo'), Object, Object),
    UnaryExpression(Keyword('isvehicleradaron'), Object, Boolean),
    UnaryExpression(Keyword('iswalking'), Object, Boolean),
    UnaryExpression(Keyword('isweapondeployed'), Object, Boolean),
    UnaryExpression(Keyword('isweaponrested'), Object, Boolean),
    UnaryExpression(Keyword('itemcargo'), Object, Array),
    UnaryExpression(Keyword('items'), Object, Array),
    UnaryExpression(Keyword('itemswithmagazines'), Object, Array),
    UnaryExpression(Keyword('keyimage'), Number, String),
    UnaryExpression(Keyword('keyname'), Number, String),
    UnaryExpression(Keyword('landresult'), Object, String),
    UnaryExpression(Keyword('lasertarget'), Object, Object),
    UnaryExpression(Keyword('lbadd'), Array, Number),
    UnaryExpression(Keyword('lbclear'), Control, Nothing),
    UnaryExpression(Keyword('lbclear'), Number, Nothing),
    UnaryExpression(Keyword('lbcolor'), Array, Array),
    UnaryExpression(Keyword('lbcolorright'), Array, Array),
    UnaryExpression(Keyword('lbcursel'), Control, Number),
    UnaryExpression(Keyword('lbcursel'), Number, Number),
    UnaryExpression(Keyword('lbdata'), Array, String),
    UnaryExpression(Keyword('lbdelete'), Array, Nothing),
    UnaryExpression(Keyword('lbpicture'), Array, String),
    UnaryExpression(Keyword('lbpictureright'), Array, String),
    UnaryExpression(Keyword('lbselection'), Control, Array),
    UnaryExpression(Keyword('lbsetcolor'), Array, Nothing),
    UnaryExpression(Keyword('lbsetcolorright'), Array, Nothing),
    UnaryExpression(Keyword('lbsetcursel'), Array, Nothing),
    UnaryExpression(Keyword('lbsetdata'), Array, Nothing),
    UnaryExpression(Keyword('lbsetpicture'), Array, Nothing),
    UnaryExpression(Keyword('lbsetpicturecolor'), Array, Nothing),
    UnaryExpression(Keyword('lbsetpicturecolordisabled'), Array, Nothing),
    UnaryExpression(Keyword('lbsetpicturecolorselected'), Array, Nothing),
    UnaryExpression(Keyword('lbsetpictureright'), Array, Nothing),
    UnaryExpression(Keyword('lbsetselectcolor'), Array, Nothing),
    UnaryExpression(Keyword('lbsetselectcolorright'), Array, Nothing),
    UnaryExpression(Keyword('lbsettext'), Array, String),
    UnaryExpression(Keyword('lbsettooltip'), Array, Nothing),
    UnaryExpression(Keyword('lbsetvalue'), Array, Nothing),
    UnaryExpression(Keyword('lbsize'), Control, Number),
    UnaryExpression(Keyword('lbsize'), Number, Number),
    UnaryExpression(Keyword('lbsort'), Control, Nothing),
    UnaryExpression(Keyword('lbsort'), Array, Nothing),
    UnaryExpression(Keyword('lbsort'), Number, Nothing),
    UnaryExpression(Keyword('lbsortbyvalue'), Control, Nothing),
    UnaryExpression(Keyword('lbsortbyvalue'), Number, Nothing),
    UnaryExpression(Keyword('lbtext'), Array, String),
    UnaryExpression(Keyword('lbtextright'), Array, String),
    UnaryExpression(Keyword('lbvalue'), Array, Number),
    UnaryExpression(Keyword('leader'), Object, Object),
    UnaryExpression(Keyword('leader'), Group, Object),
    UnaryExpression(Keyword('leader'), TeamMember, TeamMember),
    UnaryExpression(Keyword('leaderboarddeinit'), String, Boolean),
    UnaryExpression(Keyword('leaderboardgetrows'), String, Array),
    UnaryExpression(Keyword('leaderboardinit'), String, Boolean),
    UnaryExpression(Keyword('leaderboardrequestrowsfriends'), String, Boolean),
    UnaryExpression(Keyword('leaderboardrequestrowsglobal'), Array, Boolean),
    UnaryExpression(Keyword('leaderboardrequestrowsglobalarounduser'), Array, Boolean),
    UnaryExpression(Keyword('leaderboardsrequestuploadscore'), Array, Boolean),
    UnaryExpression(Keyword('leaderboardsrequestuploadscorekeepbest'), Array, Boolean),
    UnaryExpression(Keyword('leaderboardstate'), String, Number),
    UnaryExpression(Keyword('lifestate'), Object, String),
    UnaryExpression(Keyword('lightdetachobject'), Object, Nothing),
    UnaryExpression(Keyword('lightison'), Object, String),
    UnaryExpression(Keyword('linearconversion'), Array, Number),
    UnaryExpression(Keyword('lineintersects'), Array, Boolean),
    UnaryExpression(Keyword('lineintersectsobjs'), Array, Array),
    UnaryExpression(Keyword('lineintersectssurfaces'), Array, Array),
    UnaryExpression(Keyword('lineintersectswith'), Array, Array),
    UnaryExpression(Keyword('list'), Object, Array),
    UnaryExpression(Keyword('listremotetargets'), Side, Array),
    UnaryExpression(Keyword('listvehiclesensors'), Object, Array),
    UnaryExpression(Keyword('ln'), Number, Number),
    UnaryExpression(Keyword('lnbaddarray'), Array, Number),
    UnaryExpression(Keyword('lnbaddcolumn'), Array, Number),
    UnaryExpression(Keyword('lnbaddrow'), Array, Number),
    UnaryExpression(Keyword('lnbclear'), Control, Nothing),
    UnaryExpression(Keyword('lnbclear'), Number, Nothing),
    UnaryExpression(Keyword('lnbcolor'), Array, Array),
    UnaryExpression(Keyword('lnbcolorright'), Array, Array),
    UnaryExpression(Keyword('lnbcurselrow'), Control, Number),
    UnaryExpression(Keyword('lnbcurselrow'), Number, Number),
    UnaryExpression(Keyword('lnbdata'), Array, String),
    UnaryExpression(Keyword('lnbdeletecolumn'), Array, Nothing),
    UnaryExpression(Keyword('lnbdeleterow'), Array, Nothing),
    UnaryExpression(Keyword('lnbgetcolumnsposition'), Control, Array),
    UnaryExpression(Keyword('lnbgetcolumnsposition'), Number, Array),
    UnaryExpression(Keyword('lnbpicture'), Array, String),
    UnaryExpression(Keyword('lnbpictureright'), Array, String),
    UnaryExpression(Keyword('lnbsetcolor'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetcolorright'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetcolumnspos'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetcurselrow'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetdata'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetpicture'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetpicturecolor'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetpicturecolorright'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetpicturecolorselected'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetpicturecolorselectedright'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetpictureright'), Array, Nothing),
    UnaryExpression(Keyword('lnbsettext'), Array, Nothing),
    UnaryExpression(Keyword('lnbsettextright'), Array, Nothing),
    UnaryExpression(Keyword('lnbsetvalue'), Array, Nothing),
    UnaryExpression(Keyword('lnbsize'), Control, Array),
    UnaryExpression(Keyword('lnbsize'), Number, Array),
    UnaryExpression(Keyword('lnbsort'), Array, Nothing),
    UnaryExpression(Keyword('lnbsortbyvalue'), Array, Nothing),
    UnaryExpression(Keyword('lnbtext'), Array, String),
    UnaryExpression(Keyword('lnbtextright'), Array, String),
    UnaryExpression(Keyword('lnbvalue'), Array, Number),
    UnaryExpression(Keyword('load'), Object, Number),
    UnaryExpression(Keyword('loadabs'), Object, Number),
    UnaryExpression(Keyword('loadbackpack'), Object, Number),
    UnaryExpression(Keyword('loadfile'), String, String),
    UnaryExpression(Keyword('loaduniform'), Object, Number),
    UnaryExpression(Keyword('loadvest'), Object, Number),
    UnaryExpression(Keyword('local'), Object, Boolean),
    UnaryExpression(Keyword('local'), Group, Boolean),
    UnaryExpression(Keyword('localize'), String, String),
    UnaryExpression(Keyword('locationposition'), Location, Array),
    UnaryExpression(Keyword('locked'), Object, Number),
    UnaryExpression(Keyword('lockeddriver'), Object, Boolean),
    UnaryExpression(Keyword('lockidentity'), Object, Boolean),
    UnaryExpression(Keyword('log'), Number, Number),
    UnaryExpression(Keyword('lognetwork'), Array, Number),
    UnaryExpression(Keyword('lognetworkterminate'), Number, Nothing),
    UnaryExpression(Keyword('magazinecargo'), Object, Array),
    UnaryExpression(Keyword('magazines'), Object, Array),
    UnaryExpression(Keyword('magazinesallturrets'), Object, Array),
    UnaryExpression(Keyword('magazinesammo'), Object, Array),
    UnaryExpression(Keyword('magazinesammocargo'), Object, Array),
    UnaryExpression(Keyword('magazinesammofull'), Object, Array),
    UnaryExpression(Keyword('magazinesdetail'), Object, Array),
    UnaryExpression(Keyword('magazinesdetailbackpack'), Object, Array),
    UnaryExpression(Keyword('magazinesdetailuniform'), Object, Array),
    UnaryExpression(Keyword('magazinesdetailvest'), Object, Array),
    UnaryExpression(Keyword('mapanimadd'), Array, Nothing),
    UnaryExpression(Keyword('mapcenteroncamera'), Control, Array),
    UnaryExpression(Keyword('mapgridposition'), Object, String),
    UnaryExpression(Keyword('mapgridposition'), Array, String),
    UnaryExpression(Keyword('markeralpha'), String, Number),
    UnaryExpression(Keyword('markerbrush'), String, String),
    UnaryExpression(Keyword('markercolor'), String, String),
    UnaryExpression(Keyword('markerdir'), String, Number),
    UnaryExpression(Keyword('markerpos'), String, Array),
    UnaryExpression(Keyword('markershape'), String, String),
    UnaryExpression(Keyword('markersize'), String, Array),
    UnaryExpression(Keyword('markertext'), String, String),
    UnaryExpression(Keyword('markertype'), String, String),
    UnaryExpression(Keyword('members'), TeamMember, Array),
    UnaryExpression(Keyword('menuaction'), Array, String),
    UnaryExpression(Keyword('menuadd'), Array, Number),
    UnaryExpression(Keyword('menuchecked'), Array, Boolean),
    UnaryExpression(Keyword('menuclear'), Control, Nothing),
    UnaryExpression(Keyword('menuclear'), Number, Nothing),
    UnaryExpression(Keyword('menucollapse'), Array, Nothing),
    UnaryExpression(Keyword('menudata'), Array, String),
    UnaryExpression(Keyword('menudelete'), Array, Nothing),
    UnaryExpression(Keyword('menuenable'), Array, Nothing),
    UnaryExpression(Keyword('menuenabled'), Array, Boolean),
    UnaryExpression(Keyword('menuexpand'), Array, Nothing),
    UnaryExpression(Keyword('menuhover'), Control, Array),
    UnaryExpression(Keyword('menuhover'), Number, Array),
    UnaryExpression(Keyword('menupicture'), Array, String),
    UnaryExpression(Keyword('menusetaction'), Array, Nothing),
    UnaryExpression(Keyword('menusetcheck'), Array, Nothing),
    UnaryExpression(Keyword('menusetdata'), Array, Nothing),
    UnaryExpression(Keyword('menusetpicture'), Array, Nothing),
    UnaryExpression(Keyword('menusetvalue'), Array, Nothing),
    UnaryExpression(Keyword('menushortcut'), Array, Number),
    UnaryExpression(Keyword('menushortcuttext'), Array, String),
    UnaryExpression(Keyword('menusize'), Array, Number),
    UnaryExpression(Keyword('menusort'), Array, Nothing),
    UnaryExpression(Keyword('menutext'), Array, String),
    UnaryExpression(Keyword('menuurl'), Array, String),
    UnaryExpression(Keyword('menuvalue'), Array, Number),
    UnaryExpression(Keyword('mineactive'), Object, Boolean),
    UnaryExpression(Keyword('modparams'), Array, Array),
    UnaryExpression(Keyword('moonphase'), Array, Number),
    UnaryExpression(Keyword('morale'), Object, Number),
    UnaryExpression(Keyword('move3dencamera'), Array, Nothing),
    UnaryExpression(Keyword('moveout'), Object, Nothing),
    UnaryExpression(Keyword('movetime'), Object, Number),
    UnaryExpression(Keyword('movetocompleted'), Object, Boolean),
    UnaryExpression(Keyword('movetofailed'), Object, Boolean),
    UnaryExpression(Keyword('name'), Object, String),
    UnaryExpression(Keyword('name'), Location, String),
    UnaryExpression(Keyword('namesound'), Object, String),
    UnaryExpression(Keyword('nearestbuilding'), Object, Object),
    UnaryExpression(Keyword('nearestbuilding'), Array, Object),
    UnaryExpression(Keyword('nearestlocation'), Array, Location),
    UnaryExpression(Keyword('nearestlocations'), Array, Array),
    UnaryExpression(Keyword('nearestlocationwithdubbing'), Array, Location),
    UnaryExpression(Keyword('nearestobject'), Array, Object),
    UnaryExpression(Keyword('nearestobjects'), Array, Array),
    UnaryExpression(Keyword('nearestterrainobjects'), Array, Array),
    UnaryExpression(Keyword('needreload'), Object, Number),
    UnaryExpression(Keyword('netid'), Object, String),
    UnaryExpression(Keyword('netid'), Group, String),
    UnaryExpression(Keyword('nextmenuitemindex'), Control, Number),
    UnaryExpression(Keyword('not'), Boolean, Boolean),
    UnaryExpression(Keyword('numberofenginesrtd'), Object, Number),
    UnaryExpression(Keyword('numbertodate'), Array, Array),
    UnaryExpression(Keyword('objectcurators'), Object, Array),
    UnaryExpression(Keyword('objectfromnetid'), String, Object),
    UnaryExpression(Keyword('objectparent'), Object, Object),
    UnaryExpression(Keyword('onbriefinggroup'), String, Nothing),
    UnaryExpression(Keyword('onbriefingnotes'), String, Nothing),
    UnaryExpression(Keyword('onbriefingplan'), String, Nothing),
    UnaryExpression(Keyword('onbriefingteamswitch'), String, Nothing),
    UnaryExpression(Keyword('oncommandmodechanged'), Code, Nothing),
    UnaryExpression(Keyword('oncommandmodechanged'), String, Nothing),
    UnaryExpression(Keyword('oneachframe'), Code, Nothing),
    UnaryExpression(Keyword('oneachframe'), String, Nothing),
    UnaryExpression(Keyword('ongroupiconclick'), Code, Nothing),
    UnaryExpression(Keyword('ongroupiconclick'), String, Nothing),
    UnaryExpression(Keyword('ongroupiconoverenter'), Code, Nothing),
    UnaryExpression(Keyword('ongroupiconoverenter'), String, Nothing),
    UnaryExpression(Keyword('ongroupiconoverleave'), Code, Nothing),
    UnaryExpression(Keyword('ongroupiconoverleave'), String, Nothing),
    UnaryExpression(Keyword('onhcgroupselectionchanged'), Code, Nothing),
    UnaryExpression(Keyword('onhcgroupselectionchanged'), String, Nothing),
    UnaryExpression(Keyword('onmapsingleclick'), Code, Nothing),
    UnaryExpression(Keyword('onmapsingleclick'), String, Nothing),
    UnaryExpression(Keyword('onplayerconnected'), Code, Nothing),
    UnaryExpression(Keyword('onplayerconnected'), String, Nothing),
    UnaryExpression(Keyword('onplayerdisconnected'), Code, Nothing),
    UnaryExpression(Keyword('onplayerdisconnected'), String, Nothing),
    UnaryExpression(Keyword('onpreloadfinished'), Code, Nothing),
    UnaryExpression(Keyword('onpreloadfinished'), String, Nothing),
    UnaryExpression(Keyword('onpreloadstarted'), Code, Nothing),
    UnaryExpression(Keyword('onpreloadstarted'), String, Nothing),
    UnaryExpression(Keyword('onteamswitch'), Code, Nothing),
    UnaryExpression(Keyword('onteamswitch'), String, Nothing),
    UnaryExpression(Keyword('opendlcpage'), Number, Boolean),
    UnaryExpression(Keyword('openmap'), Array, Boolean),
    UnaryExpression(Keyword('openmap'), Boolean, Boolean),
    UnaryExpression(Keyword('openyoutubevideo'), String, Boolean),
    UnaryExpression(Keyword('owner'), Object, Number),
    UnaryExpression(Keyword('param'), Array, Anything),
    UnaryExpression(Keyword('params'), Array, Boolean),
    UnaryExpression(Keyword('parsenumber'), String, Number),
    UnaryExpression(Keyword('parsenumber'), Boolean, Number),
    UnaryExpression(Keyword('parsesimplearray'), String, Array),
    UnaryExpression(Keyword('parsetext'), String, String),
    UnaryExpression(Keyword('pickweaponpool'), Object, Nothing),
    UnaryExpression(Keyword('pitch'), Object, String),
    UnaryExpression(Keyword('playableslotsnumber'), Side, Number),
    UnaryExpression(Keyword('playersnumber'), Side, Number),
    UnaryExpression(Keyword('playmission'), Array, Nothing),
    UnaryExpression(Keyword('playmusic'), String, Nothing),
    UnaryExpression(Keyword('playmusic'), Array, Nothing),
    UnaryExpression(Keyword('playscriptedmission'), Array, Nothing),
    UnaryExpression(Keyword('playsound'), String, Nothing),
    UnaryExpression(Keyword('playsound'), Array, Nothing),
    UnaryExpression(Keyword('playsound3d'), Array, Nothing),
    UnaryExpression(Keyword('position'), Object, Array),
    UnaryExpression(Keyword('position'), Location, Array),
    UnaryExpression(Keyword('positioncameratoworld'), Array, Array),
    UnaryExpression(Keyword('ppeffectcommitted'), String, Boolean),
    UnaryExpression(Keyword('ppeffectcommitted'), Number, Boolean),
    UnaryExpression(Keyword('ppeffectcreate'), Array, Anything),
    UnaryExpression(Keyword('ppeffectdestroy'), Number, Nothing),
    UnaryExpression(Keyword('ppeffectdestroy'), Array, Nothing),
    UnaryExpression(Keyword('ppeffectenabled'), Number, Boolean),
    UnaryExpression(Keyword('precision'), Object, Number),
    UnaryExpression(Keyword('preloadcamera'), Array, Boolean),
    UnaryExpression(Keyword('preloadsound'), String, Boolean),
    UnaryExpression(Keyword('preloadtitleobj'), Array, Boolean),
    UnaryExpression(Keyword('preloadtitlersc'), Array, Boolean),
    UnaryExpression(Keyword('preprocessfile'), String, String),
    UnaryExpression(Keyword('preprocessfilelinenumbers'), String, String),
    UnaryExpression(Keyword('primaryweapon'), Object, String),
    UnaryExpression(Keyword('primaryweaponitems'), Object, Array),
    UnaryExpression(Keyword('primaryweaponmagazine'), Object, Array),
    UnaryExpression(Keyword('priority'), Task, Number),
    UnaryExpression(Keyword('private'), String, Nothing),
    UnaryExpression(Keyword('private'), Array, Nothing),
    UnaryExpression(Keyword('processdiarylink'), String, Nothing),
    UnaryExpression(Keyword('progressloadingscreen'), Number, Nothing),
    UnaryExpression(Keyword('progressposition'), Control, Number),
    UnaryExpression(Keyword('publicvariable'), String, Nothing),
    UnaryExpression(Keyword('publicvariableserver'), String, Nothing),
    UnaryExpression(Keyword('putweaponpool'), Object, Nothing),
    UnaryExpression(Keyword('queryitemspool'), String, Number),
    UnaryExpression(Keyword('querymagazinepool'), String, Number),
    UnaryExpression(Keyword('queryweaponpool'), String, Number),
    UnaryExpression(Keyword('rad'), Number, Number),
    UnaryExpression(Keyword('radiochannelcreate'), Array, Number),
    UnaryExpression(Keyword('random'), Array, Number),
    UnaryExpression(Keyword('random'), Number, Number),
    UnaryExpression(Keyword('rank'), Object, String),
    UnaryExpression(Keyword('rankid'), Object, Number),
    UnaryExpression(Keyword('rating'), Object, Number),
    UnaryExpression(Keyword('rectangular'), Location, Boolean),
    UnaryExpression(Keyword('registeredtasks'), TeamMember, Array),
    UnaryExpression(Keyword('reload'), Object, Nothing),
    UnaryExpression(Keyword('reloadenabled'), Object, Boolean),
    UnaryExpression(Keyword('remoteexec'), Array, Anything),
    UnaryExpression(Keyword('remoteexeccall'), Array, Anything),
    UnaryExpression(Keyword('remove3denconnection'), Array, Nothing),
    UnaryExpression(Keyword('remove3deneventhandler'), Array, Nothing),
    UnaryExpression(Keyword('remove3denlayer'), Number, Boolean),
    UnaryExpression(Keyword('removeall3deneventhandlers'), String, Nothing),
    UnaryExpression(Keyword('removeallactions'), Object, Nothing),
    UnaryExpression(Keyword('removeallassigneditems'), Object, Nothing),
    UnaryExpression(Keyword('removeallcontainers'), Object, Nothing),
    UnaryExpression(Keyword('removeallcuratoraddons'), Object, Nothing),
    UnaryExpression(Keyword('removeallcuratorcameraareas'), Object, Nothing),
    UnaryExpression(Keyword('removeallcuratoreditingareas'), Object, Nothing),
    UnaryExpression(Keyword('removeallhandgunitems'), Object, Nothing),
    UnaryExpression(Keyword('removeallitems'), Object, Nothing),
    UnaryExpression(Keyword('removeallitemswithmagazines'), Object, Nothing),
    UnaryExpression(Keyword('removeallmissioneventhandlers'), String, Nothing),
    UnaryExpression(Keyword('removeallmusiceventhandlers'), String, Nothing),
    UnaryExpression(Keyword('removeallownedmines'), Object, Nothing),
    UnaryExpression(Keyword('removeallprimaryweaponitems'), Object, Nothing),
    UnaryExpression(Keyword('removeallweapons'), Object, Nothing),
    UnaryExpression(Keyword('removebackpack'), Object, Nothing),
    UnaryExpression(Keyword('removebackpackglobal'), Object, Nothing),
    UnaryExpression(Keyword('removefromremainscollector'), Array, Nothing),
    UnaryExpression(Keyword('removegoggles'), Object, Nothing),
    UnaryExpression(Keyword('removeheadgear'), Object, Nothing),
    UnaryExpression(Keyword('removemissioneventhandler'), Array, Nothing),
    UnaryExpression(Keyword('removemusiceventhandler'), Array, Nothing),
    UnaryExpression(Keyword('removeswitchableunit'), Object, Nothing),
    UnaryExpression(Keyword('removeuniform'), Object, Nothing),
    UnaryExpression(Keyword('removevest'), Object, Nothing),
    UnaryExpression(Keyword('requiredversion'), String, Boolean),
    UnaryExpression(Keyword('resetsubgroupdirection'), Object, Nothing),
    UnaryExpression(Keyword('resources'), TeamMember, Array),
    UnaryExpression(Keyword('restarteditorcamera'), Control, Nothing),
    UnaryExpression(Keyword('reverse'), Array, Nothing),
    UnaryExpression(Keyword('roadat'), Object, Object),
    UnaryExpression(Keyword('roadat'), Array, Object),
    UnaryExpression(Keyword('roadsconnectedto'), Object, Array),
    UnaryExpression(Keyword('roledescription'), Object, String),
    UnaryExpression(Keyword('ropeattachedobjects'), Object, Array),
    UnaryExpression(Keyword('ropeattachedto'), Object, Object),
    UnaryExpression(Keyword('ropeattachenabled'), Object, Boolean),
    UnaryExpression(Keyword('ropecreate'), Array, Object),
    UnaryExpression(Keyword('ropecut'), Array, Nothing),
    UnaryExpression(Keyword('ropedestroy'), Object, Nothing),
    UnaryExpression(Keyword('ropeendposition'), Object, Array),
    UnaryExpression(Keyword('ropelength'), Object, Number),
    UnaryExpression(Keyword('ropes'), Object, Array),
    UnaryExpression(Keyword('ropeunwind'), Array, Nothing),
    UnaryExpression(Keyword('ropeunwound'), Object, Boolean),
    UnaryExpression(Keyword('rotorsforcesrtd'), Object, Array),
    UnaryExpression(Keyword('rotorsrpmrtd'), Object, Array),
    UnaryExpression(Keyword('round'), Number, Number),
    UnaryExpression(Keyword('save3deninventory'), Array, Nothing),
    UnaryExpression(Keyword('saveoverlay'), Control, Nothing),
    UnaryExpression(Keyword('savevar'), String, Nothing),
    UnaryExpression(Keyword('scopename'), String, Nothing),
    UnaryExpression(Keyword('score'), Object, Number),
    UnaryExpression(Keyword('scoreside'), Side, Number),
    UnaryExpression(Keyword('screenshot'), String, Boolean),
    UnaryExpression(Keyword('screentoworld'), Array, Array),
    UnaryExpression(Keyword('scriptdone'), Script, Boolean),
    UnaryExpression(Keyword('scriptname'), String, Nothing),
    UnaryExpression(Keyword('scudstate'), Object, Number),
    UnaryExpression(Keyword('secondaryweapon'), Object, String),
    UnaryExpression(Keyword('secondaryweaponitems'), Object, Array),
    UnaryExpression(Keyword('secondaryweaponmagazine'), Object, Array),
    UnaryExpression(Keyword('selectbestplaces'), Array, Array),
    UnaryExpression(Keyword('selectededitorobjects'), Control, Nothing),
    UnaryExpression(Keyword('selectionnames'), Object, Array),
    UnaryExpression(Keyword('selectmax'), Array, Anything),
    UnaryExpression(Keyword('selectmin'), Array, Anything),
    UnaryExpression(Keyword('selectplayer'), Object, Nothing),
    UnaryExpression(Keyword('selectrandom'), Array, Anything),
    UnaryExpression(Keyword('selectrandomweighted'), Array, Anything),
    UnaryExpression(Keyword('sendaumessage'), Array, Nothing),
    UnaryExpression(Keyword('sendudpmessage'), Array, Boolean),
    UnaryExpression(Keyword('servercommand'), String, Boolean),
    UnaryExpression(Keyword('servercommandavailable'), String, Boolean),
    UnaryExpression(Keyword('servercommandexecutable'), String, Boolean),
    UnaryExpression(Keyword('set3denattributes'), Array, Boolean),
    UnaryExpression(Keyword('set3dengrid'), Array, Nothing),
    UnaryExpression(Keyword('set3deniconsvisible'), Array, Nothing),
    UnaryExpression(Keyword('set3denlinesvisible'), Array, Nothing),
    UnaryExpression(Keyword('set3denmissionattributes'), Array, Nothing),
    UnaryExpression(Keyword('set3denmodelsvisible'), Array, Nothing),
    UnaryExpression(Keyword('set3denselected'), Array, Nothing),
    UnaryExpression(Keyword('setacctime'), Number, Nothing),
    UnaryExpression(Keyword('setaperture'), Number, Nothing),
    UnaryExpression(Keyword('setaperturenew'), Array, Nothing),
    UnaryExpression(Keyword('setarmorypoints'), Number, Nothing),
    UnaryExpression(Keyword('setcamshakedefparams'), Array, Nothing),
    UnaryExpression(Keyword('setcamshakeparams'), Array, Nothing),
    UnaryExpression(Keyword('setcompassoscillation'), Array, Nothing),
    UnaryExpression(Keyword('setcurrentchannel'), Number, Boolean),
    UnaryExpression(Keyword('setdate'), Array, Nothing),
    UnaryExpression(Keyword('setdefaultcamera'), Array, Nothing),
    UnaryExpression(Keyword('setdetailmapblendpars'), Array, Nothing),
    UnaryExpression(Keyword('setgroupiconsselectable'), Boolean, Nothing),
    UnaryExpression(Keyword('setgroupiconsvisible'), Array, Nothing),
    UnaryExpression(Keyword('sethorizonparallaxcoef'), Number, Nothing),
    UnaryExpression(Keyword('sethudmovementlevels'), Array, Nothing),
    UnaryExpression(Keyword('setinfopanel'), Array, Boolean),
    UnaryExpression(Keyword('setlocalwindparams'), Array, Nothing),
    UnaryExpression(Keyword('setmouseposition'), Array, Nothing),
    UnaryExpression(Keyword('setmusiceventhandler'), Array, Nothing),
    UnaryExpression(Keyword('setobjectviewdistance'), Number, Nothing),
    UnaryExpression(Keyword('setobjectviewdistance'), Array, Nothing),
    UnaryExpression(Keyword('setplayable'), Object, Nothing),
    UnaryExpression(Keyword('setplayerrespawntime'), Number, Nothing),
    UnaryExpression(Keyword('setshadowdistance'), Number, Nothing),
    UnaryExpression(Keyword('setsimulweatherlayers'), Number, Nothing),
    UnaryExpression(Keyword('setstaminascheme'), String, Nothing),
    UnaryExpression(Keyword('setstatvalue'), Array, Boolean),
    UnaryExpression(Keyword('setsystemofunits'), Number, Nothing),
    UnaryExpression(Keyword('setterraingrid'), Number, Nothing),
    UnaryExpression(Keyword('settimemultiplier'), Number, Nothing),
    UnaryExpression(Keyword('settrafficdensity'), Array, Nothing),
    UnaryExpression(Keyword('settrafficdistance'), Number, Nothing),
    UnaryExpression(Keyword('settrafficgap'), Array, Nothing),
    UnaryExpression(Keyword('settrafficspeed'), Array, Nothing),
    UnaryExpression(Keyword('setviewdistance'), Number, Nothing),
    UnaryExpression(Keyword('setwind'), Array, Nothing),
    UnaryExpression(Keyword('setwinddir'), Array, Nothing),
    UnaryExpression(Keyword('showchat'), Boolean, Nothing),
    UnaryExpression(Keyword('showcinemaborder'), Boolean, Nothing),
    UnaryExpression(Keyword('showcommandingmenu'), String, Nothing),
    UnaryExpression(Keyword('showcompass'), Boolean, Nothing),
    UnaryExpression(Keyword('showcuratorcompass'), Boolean, Nothing),
    UnaryExpression(Keyword('showgps'), Boolean, Nothing),
    UnaryExpression(Keyword('showhud'), Boolean, Nothing),
    UnaryExpression(Keyword('showhud'), Array, Nothing),
    UnaryExpression(Keyword('showmap'), Boolean, Nothing),
    UnaryExpression(Keyword('showpad'), Boolean, Nothing),
    UnaryExpression(Keyword('showradio'), Boolean, Nothing),
    UnaryExpression(Keyword('showscoretable'), Number, Nothing),
    UnaryExpression(Keyword('showsubtitles'), Boolean, Boolean),
    UnaryExpression(Keyword('showuavfeed'), Boolean, Nothing),
    UnaryExpression(Keyword('showwarrant'), Boolean, Nothing),
    UnaryExpression(Keyword('showwatch'), Boolean, Nothing),
    UnaryExpression(Keyword('showwaypoints'), Boolean, Nothing),
    UnaryExpression(Keyword('side'), Object, Side),
    UnaryExpression(Keyword('side'), Group, Side),
    UnaryExpression(Keyword('side'), Location, Side),
    UnaryExpression(Keyword('simpletasks'), Object, Array),
    UnaryExpression(Keyword('simulationenabled'), Object, Boolean),
    UnaryExpression(Keyword('simulclouddensity'), Array, Number),
    UnaryExpression(Keyword('simulcloudocclusion'), Array, Number),
    UnaryExpression(Keyword('simulinclouds'), Array, Boolean),
    UnaryExpression(Keyword('sin'), Number, Number),
    UnaryExpression(Keyword('size'), Location, Array),
    UnaryExpression(Keyword('sizeof'), String, Number),
    UnaryExpression(Keyword('skill'), Object, Number),
    UnaryExpression(Keyword('skiptime'), Number, Nothing),
    UnaryExpression(Keyword('sleep'), Number, Nothing),
    UnaryExpression(Keyword('sliderposition'), Control, Number),
    UnaryExpression(Keyword('sliderposition'), Number, Number),
    UnaryExpression(Keyword('sliderrange'), Control, Array),
    UnaryExpression(Keyword('sliderrange'), Number, Array),
    UnaryExpression(Keyword('slidersetposition'), Array, Nothing),
    UnaryExpression(Keyword('slidersetrange'), Array, Nothing),
    UnaryExpression(Keyword('slidersetspeed'), Array, Nothing),
    UnaryExpression(Keyword('sliderspeed'), Control, Array),
    UnaryExpression(Keyword('sliderspeed'), Number, Array),
    UnaryExpression(Keyword('soldiermagazines'), Object, Array),
    UnaryExpression(Keyword('someammo'), Object, Boolean),
    UnaryExpression(Keyword('speaker'), Object, String),
    UnaryExpression(Keyword('speed'), Object, Number),
    UnaryExpression(Keyword('speedmode'), Object, String),
    UnaryExpression(Keyword('speedmode'), Group, String),
    UnaryExpression(Keyword('sqrt'), Number, Number),
    UnaryExpression(Keyword('squadparams'), Object, Array),
    UnaryExpression(Keyword('stance'), Object, String),
    UnaryExpression(Keyword('startloadingscreen'), Array, Nothing),
    UnaryExpression(Keyword('stopenginertd'), Object, Nothing),
    UnaryExpression(Keyword('stopped'), Object, Boolean),
    UnaryExpression(Keyword('str'), Type, String),
    UnaryExpression(Keyword('supportinfo'), String, Array),
    UnaryExpression(Keyword('surfaceiswater'), Array, Boolean),
    UnaryExpression(Keyword('surfacenormal'), Array, Array),
    UnaryExpression(Keyword('surfacetype'), Array, String),
    UnaryExpression(Keyword('switch'), Type, SwitchType),
    UnaryExpression(Keyword('switchcamera'), Object, Nothing),
    UnaryExpression(Keyword('synchronizedobjects'), Object, Array),
    UnaryExpression(Keyword('synchronizedtriggers'), Array, Array),
    UnaryExpression(Keyword('synchronizedwaypoints'), Object, Array),
    UnaryExpression(Keyword('synchronizedwaypoints'), Array, Array),
    UnaryExpression(Keyword('systemchat'), String, Nothing),
    UnaryExpression(Keyword('tan'), Number, Number),
    UnaryExpression(Keyword('taskalwaysvisible'), Task, Boolean),
    UnaryExpression(Keyword('taskchildren'), Task, Array),
    UnaryExpression(Keyword('taskcompleted'), Task, Boolean),
    UnaryExpression(Keyword('taskcustomdata'), Task, Array),
    UnaryExpression(Keyword('taskdescription'), Task, Array),
    UnaryExpression(Keyword('taskdestination'), Task, Array),
    UnaryExpression(Keyword('taskhint'), Array, Nothing),
    UnaryExpression(Keyword('taskmarkeroffset'), Object, Array),
    UnaryExpression(Keyword('taskparent'), Task, Task),
    UnaryExpression(Keyword('taskresult'), Task, Array),
    UnaryExpression(Keyword('taskstate'), Task, String),
    UnaryExpression(Keyword('tasktype'), Task, String),
    UnaryExpression(Keyword('teammember'), Object, TeamMember),
    UnaryExpression(Keyword('teamname'), TeamMember, String),
    UnaryExpression(Keyword('teamtype'), TeamMember, String),
    UnaryExpression(Keyword('terminate'), Script, Nothing),
    UnaryExpression(Keyword('terrainintersect'), Array, Boolean),
    UnaryExpression(Keyword('terrainintersectasl'), Array, Boolean),
    UnaryExpression(Keyword('terrainintersectatasl'), Array, Array),
    UnaryExpression(Keyword('text'), String, String),
    UnaryExpression(Keyword('text'), Location, String),
    UnaryExpression(Keyword('textlog'), Type, Nothing),
    UnaryExpression(Keyword('textlogformat'), Array, Nothing),
    UnaryExpression(Keyword('tg'), Number, Number),
    UnaryExpression(Keyword('throw'), Type, Nothing),
    UnaryExpression(Keyword('titlecut'), Array, Nothing),
    UnaryExpression(Keyword('titlefadeout'), Number, Nothing),
    UnaryExpression(Keyword('titleobj'), Array, Nothing),
    UnaryExpression(Keyword('titlersc'), Array, Nothing),
    UnaryExpression(Keyword('titletext'), Array, Nothing),
    UnaryExpression(Keyword('toarray'), String, Array),
    UnaryExpression(Keyword('tofixed'), Number, Nothing),
    UnaryExpression(Keyword('tolower'), String, String),
    UnaryExpression(Keyword('tostring'), Array, String),
    UnaryExpression(Keyword('toupper'), String, String),
    UnaryExpression(Keyword('triggeractivated'), Object, Boolean),
    UnaryExpression(Keyword('triggeractivation'), Object, Array),
    UnaryExpression(Keyword('triggerarea'), Object, Array),
    UnaryExpression(Keyword('triggerattachedvehicle'), Object, Object),
    UnaryExpression(Keyword('triggerstatements'), Object, Array),
    UnaryExpression(Keyword('triggertext'), Object, String),
    UnaryExpression(Keyword('triggertimeout'), Object, Array),
    UnaryExpression(Keyword('triggertimeoutcurrent'), Object, Number),
    UnaryExpression(Keyword('triggertype'), Object, String),
    UnaryExpression(Keyword('try'), Code, TryType),
    UnaryExpression(Keyword('tvadd'), Array, Number),
    UnaryExpression(Keyword('tvclear'), Number, Nothing),
    UnaryExpression(Keyword('tvclear'), Control, Nothing),
    UnaryExpression(Keyword('tvcollapse'), Array, Nothing),
    UnaryExpression(Keyword('tvcollapseall'), Number, Nothing),
    UnaryExpression(Keyword('tvcollapseall'), Control, Nothing),
    UnaryExpression(Keyword('tvcount'), Array, Number),
    UnaryExpression(Keyword('tvcursel'), Number, Array),
    UnaryExpression(Keyword('tvcursel'), Control, Array),
    UnaryExpression(Keyword('tvdata'), Array, String),
    UnaryExpression(Keyword('tvdelete'), Array, Nothing),
    UnaryExpression(Keyword('tvexpand'), Array, Nothing),
    UnaryExpression(Keyword('tvexpandall'), Number, Nothing),
    UnaryExpression(Keyword('tvexpandall'), Control, Nothing),
    UnaryExpression(Keyword('tvpicture'), Array, String),
    UnaryExpression(Keyword('tvpictureright'), Array, String),
    UnaryExpression(Keyword('tvsetcursel'), Array, Nothing),
    UnaryExpression(Keyword('tvsetdata'), Array, Nothing),
    UnaryExpression(Keyword('tvsetpicture'), Array, Nothing),
    UnaryExpression(Keyword('tvsetpicturecolor'), Array, Nothing),
    UnaryExpression(Keyword('tvsetpictureright'), Array, Nothing),
    UnaryExpression(Keyword('tvsetpicturerightcolor'), Array, Nothing),
    UnaryExpression(Keyword('tvsettext'), Array, String),
    UnaryExpression(Keyword('tvsettooltip'), Array, Nothing),
    UnaryExpression(Keyword('tvsetvalue'), Array, Nothing),
    UnaryExpression(Keyword('tvsort'), Array, Nothing),
    UnaryExpression(Keyword('tvsortbyvalue'), Array, Nothing),
    UnaryExpression(Keyword('tvtext'), Array, String),
    UnaryExpression(Keyword('tvtooltip'), Array, String),
    UnaryExpression(Keyword('tvvalue'), Array, Number),
    UnaryExpression(Keyword('type'), Task, String),
    UnaryExpression(Keyword('type'), Location, String),
    UnaryExpression(Keyword('typename'), Type, String),
    UnaryExpression(Keyword('typeof'), Object, String),
    UnaryExpression(Keyword('uavcontrol'), Object, Array),
    UnaryExpression(Keyword('uisleep'), Number, Nothing),
    UnaryExpression(Keyword('unassigncurator'), Object, Nothing),
    UnaryExpression(Keyword('unassignteam'), Object, Nothing),
    UnaryExpression(Keyword('unassignvehicle'), Object, Nothing),
    UnaryExpression(Keyword('underwater'), Object, Boolean),
    UnaryExpression(Keyword('uniform'), Object, String),
    UnaryExpression(Keyword('uniformcontainer'), Object, Object),
    UnaryExpression(Keyword('uniformitems'), Object, Array),
    UnaryExpression(Keyword('uniformmagazines'), Object, Array),
    UnaryExpression(Keyword('unitaddons'), String, Array),
    UnaryExpression(Keyword('unitaimposition'), Object, Array),
    UnaryExpression(Keyword('unitaimpositionvisual'), Object, Array),
    UnaryExpression(Keyword('unitbackpack'), Object, Object),
    UnaryExpression(Keyword('unitisuav'), Object, Boolean),
    UnaryExpression(Keyword('unitpos'), Object, String),
    UnaryExpression(Keyword('unitready'), Object, Boolean),
    UnaryExpression(Keyword('unitready'), Array, Boolean),
    UnaryExpression(Keyword('unitrecoilcoefficient'), Object, Number),
    UnaryExpression(Keyword('units'), Group, Array),
    UnaryExpression(Keyword('units'), Object, Array),
    UnaryExpression(Keyword('unlockachievement'), String, Boolean),
    UnaryExpression(Keyword('updateobjecttree'), Control, Nothing),
    UnaryExpression(Keyword('useaiopermapobstructiontest'), Boolean, Nothing),
    UnaryExpression(Keyword('useaisteeringcomponent'), Boolean, Nothing),
    UnaryExpression(Keyword('vectordir'), Object, Array),
    UnaryExpression(Keyword('vectordirvisual'), Object, Array),
    UnaryExpression(Keyword('vectormagnitude'), Array, Number),
    UnaryExpression(Keyword('vectormagnitudesqr'), Array, Number),
    UnaryExpression(Keyword('vectornormalized'), Array, Array),
    UnaryExpression(Keyword('vectorup'), Object, Array),
    UnaryExpression(Keyword('vectorupvisual'), Object, Array),
    UnaryExpression(Keyword('vehicle'), Object, Object),
    UnaryExpression(Keyword('vehiclecargoenabled'), Object, Boolean),
    UnaryExpression(Keyword('vehiclereceiveremotetargets'), Object, Boolean),
    UnaryExpression(Keyword('vehiclereportownposition'), Object, Boolean),
    UnaryExpression(Keyword('vehiclereportremotetargets'), Object, Boolean),
    UnaryExpression(Keyword('vehiclevarname'), Object, String),
    UnaryExpression(Keyword('velocity'), Object, Array),
    UnaryExpression(Keyword('velocitymodelspace'), Object, Array),
    UnaryExpression(Keyword('verifysignature'), String, Boolean),
    UnaryExpression(Keyword('vest'), Object, String),
    UnaryExpression(Keyword('vestcontainer'), Object, Object),
    UnaryExpression(Keyword('vestitems'), Object, Array),
    UnaryExpression(Keyword('vestmagazines'), Object, Array),
    UnaryExpression(Keyword('visibleposition'), Object, Array),
    UnaryExpression(Keyword('visiblepositionasl'), Object, Array),
    UnaryExpression(Keyword('waituntil'), Code, Nothing),
    UnaryExpression(Keyword('waypointattachedobject'), Array, Object),
    UnaryExpression(Keyword('waypointattachedvehicle'), Array, Object),
    UnaryExpression(Keyword('waypointbehaviour'), Array, String),
    UnaryExpression(Keyword('waypointcombatmode'), Array, String),
    UnaryExpression(Keyword('waypointcompletionradius'), Array, Number),
    UnaryExpression(Keyword('waypointdescription'), Array, String),
    UnaryExpression(Keyword('waypointforcebehaviour'), Array, Boolean),
    UnaryExpression(Keyword('waypointformation'), Array, String),
    UnaryExpression(Keyword('waypointhouseposition'), Array, Number),
    UnaryExpression(Keyword('waypointloiterradius'), Array, Number),
    UnaryExpression(Keyword('waypointloitertype'), Array, String),
    UnaryExpression(Keyword('waypointname'), Array, String),
    UnaryExpression(Keyword('waypointposition'), Array, Array),
    UnaryExpression(Keyword('waypoints'), Object, Array),
    UnaryExpression(Keyword('waypoints'), Group, Array),
    UnaryExpression(Keyword('waypointscript'), Array, String),
    UnaryExpression(Keyword('waypointsenableduav'), Object, Boolean),
    UnaryExpression(Keyword('waypointshow'), Array, String),
    UnaryExpression(Keyword('waypointspeed'), Array, String),
    UnaryExpression(Keyword('waypointstatements'), Array, Array),
    UnaryExpression(Keyword('waypointtimeout'), Array, Array),
    UnaryExpression(Keyword('waypointtimeoutcurrent'), Group, Number),
    UnaryExpression(Keyword('waypointtype'), Array, String),
    UnaryExpression(Keyword('waypointvisible'), Array, Number),
    UnaryExpression(Keyword('weaponcargo'), Object, Array),
    UnaryExpression(Keyword('weaponinertia'), Object, Array),
    UnaryExpression(Keyword('weaponlowered'), Object, Boolean),
    UnaryExpression(Keyword('weapons'), Object, Array),
    UnaryExpression(Keyword('weaponsitems'), Object, Array),
    UnaryExpression(Keyword('weaponsitemscargo'), Object, Array),
    UnaryExpression(Keyword('weaponstate'), Object, Array),
    UnaryExpression(Keyword('weaponstate'), Array, Array),
    UnaryExpression(Keyword('weightrtd'), Object, Array),
    UnaryExpression(Keyword('wfsidetext'), Side, String),
    UnaryExpression(Keyword('wfsidetext'), Object, String),
    UnaryExpression(Keyword('wfsidetext'), Group, String),
    UnaryExpression(Keyword('while'), Code, WhileType),
    UnaryExpression(Keyword('wingsforcesrtd'), Object, Array),
    UnaryExpression(Keyword('with'), Namespace, WithType),
    UnaryExpression(Keyword('worldtoscreen'), Array, Array),
    BinaryExpression(Object, Keyword('action'), Array, Nothing),
    BinaryExpression(Object, Keyword('actionparams'), Number, Array),
    BinaryExpression(Number, Keyword('add3denlayer'), String, Number),
    BinaryExpression(Object, Keyword('addaction'), Array, Number),
    BinaryExpression(Object, Keyword('addbackpack'), String, Nothing),
    BinaryExpression(Object, Keyword('addbackpackcargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('addbackpackcargoglobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('addbackpackglobal'), String, Nothing),
    BinaryExpression(Object, Keyword('addcuratoraddons'), Array, Nothing),
    BinaryExpression(Object, Keyword('addcuratorcameraarea'), Array, Nothing),
    BinaryExpression(Object, Keyword('addcuratoreditableobjects'), Array, Nothing),
    BinaryExpression(Object, Keyword('addcuratoreditingarea'), Array, Nothing),
    BinaryExpression(Object, Keyword('addcuratorpoints'), Number, Nothing),
    BinaryExpression(Control, Keyword('addeditorobject'), Array, String),
    BinaryExpression(Object, Keyword('addeventhandler'), Array, Number),
    BinaryExpression(Object, Keyword('addforce'), Array, Nothing),
    BinaryExpression(Object, Keyword('addgoggles'), String, Nothing),
    BinaryExpression(Group, Keyword('addgroupicon'), Array, Number),
    BinaryExpression(Object, Keyword('addhandgunitem'), String, Nothing),
    BinaryExpression(Object, Keyword('addheadgear'), String, Nothing),
    BinaryExpression(Object, Keyword('additem'), String, Nothing),
    BinaryExpression(Object, Keyword('additemcargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('additemcargoglobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('additemtobackpack'), String, Nothing),
    BinaryExpression(Object, Keyword('additemtouniform'), String, Nothing),
    BinaryExpression(Object, Keyword('additemtovest'), String, Nothing),
    BinaryExpression(Object, Keyword('addlivestats'), Number, Nothing),
    BinaryExpression(Object, Keyword('addmagazine'), String, Nothing),
    BinaryExpression(Object, Keyword('addmagazine'), Array, Nothing),
    BinaryExpression(Object, Keyword('addmagazineammocargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('addmagazinecargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('addmagazinecargoglobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('addmagazineglobal'), String, Nothing),
    BinaryExpression(Object, Keyword('addmagazines'), Array, Nothing),
    BinaryExpression(Object, Keyword('addmagazineturret'), Array, Nothing),
    BinaryExpression(Control, Keyword('addmenu'), Array, Number),
    BinaryExpression(Control, Keyword('addmenuitem'), Array, Number),
    BinaryExpression(Object, Keyword('addmpeventhandler'), Array, Number),
    BinaryExpression(Object, Keyword('addownedmine'), Object, Nothing),
    BinaryExpression(Object, Keyword('addplayerscores'), Array, Nothing),
    BinaryExpression(Object, Keyword('addprimaryweaponitem'), String, Nothing),
    BinaryExpression(String, Keyword('addpublicvariableeventhandler'), Code, Nothing),
    BinaryExpression(String, Keyword('addpublicvariableeventhandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('addrating'), Number, Nothing),
    BinaryExpression(TeamMember, Keyword('addresources'), Array, Nothing),
    BinaryExpression(Object, Keyword('addscore'), Number, Nothing),
    BinaryExpression(Side, Keyword('addscoreside'), Number, Nothing),
    BinaryExpression(Object, Keyword('addsecondaryweaponitem'), String, Nothing),
    BinaryExpression(TeamMember, Keyword('addteammember'), TeamMember, Nothing),
    BinaryExpression(Object, Keyword('addtorque'), Array, Nothing),
    BinaryExpression(Object, Keyword('adduniform'), String, Nothing),
    BinaryExpression(Group, Keyword('addvehicle'), Object, Nothing),
    BinaryExpression(Object, Keyword('addvest'), String, Nothing),
    BinaryExpression(Group, Keyword('addwaypoint'), Array, Array),
    BinaryExpression(Object, Keyword('addweapon'), String, Nothing),
    BinaryExpression(Object, Keyword('addweaponcargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('addweaponcargoglobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('addweaponglobal'), String, Nothing),
    BinaryExpression(Object, Keyword('addweaponitem'), Array, Nothing),
    BinaryExpression(Object, Keyword('addweaponturret'), Array, Nothing),
    BinaryExpression(Object, Keyword('aimedattarget'), Array, Number),
    BinaryExpression(Control, Keyword('allow3dmode'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowcrewinimmobile'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowcuratorlogicignoreareas'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowdamage'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowdammage'), Boolean, Nothing),
    BinaryExpression(Control, Keyword('allowfileoperations'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowfleeing'), Number, Nothing),
    BinaryExpression(Group, Keyword('allowfleeing'), Number, Nothing),
    BinaryExpression(Array, Keyword('allowgetin'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowsprint'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('ammo'), String, Number),
    BinaryExpression(Object, Keyword('ammoonpylon'), String, Number),
    BinaryExpression(Object, Keyword('ammoonpylon'), Number, Number),
    BinaryExpression(Boolean, Keyword('and'), Boolean, Boolean),
    BinaryExpression(Boolean, Keyword('and'), Code, Boolean),
    BinaryExpression(Object, Keyword('animate'), Array, Nothing),
    BinaryExpression(Object, Keyword('animatebay'), Array, Nothing),
    BinaryExpression(Object, Keyword('animatedoor'), Array, Nothing),
    BinaryExpression(Object, Keyword('animatepylon'), Array, Nothing),
    BinaryExpression(Object, Keyword('animatesource'), Array, Nothing),
    BinaryExpression(Object, Keyword('animationphase'), String, Number),
    BinaryExpression(Object, Keyword('animationsourcephase'), String, Number),
    BinaryExpression(Array, Keyword('append'), Array, Nothing),
    BinaryExpression(Array, Keyword('apply'), Code, Array),
    BinaryExpression(Array, Keyword('arrayintersect'), Array, Array),
    BinaryExpression(Object, Keyword('assignascargo'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignascargoindex'), Array, Nothing),
    BinaryExpression(Object, Keyword('assignascommander'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignasdriver'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignasgunner'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignasturret'), Array, Nothing),
    BinaryExpression(Object, Keyword('assigncurator'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignitem'), String, Nothing),
    BinaryExpression(Object, Keyword('assignteam'), String, Nothing),
    BinaryExpression(Object, Keyword('assigntoairport'), Object, Nothing),
    BinaryExpression(Object, Keyword('assigntoairport'), Number, Nothing),
    BinaryExpression(Number, Keyword('atan2'), Number, Number),
    BinaryExpression(Location, Keyword('attachobject'), Object, Nothing),
    BinaryExpression(Object, Keyword('attachto'), Array, Nothing),
    BinaryExpression(Object, Keyword('backpackspacefor'), String, Array),
    BinaryExpression(Type, Keyword('breakout'), String, Anything),
    BinaryExpression(Object, Keyword('buildingexit'), Number, Array),
    BinaryExpression(Object, Keyword('buildingpos'), Number, Array),
    BinaryExpression(Control, Keyword('buttonsetaction'), String, Nothing),
    BinaryExpression(Type, Keyword('call'), Code, Anything),
    BinaryExpression(String, Keyword('callextension'), String, String),
    BinaryExpression(String, Keyword('callextension'), Array, Array),
    BinaryExpression(Object, Keyword('camcommand'), String, Nothing),
    BinaryExpression(Object, Keyword('camcommit'), Number, Nothing),
    BinaryExpression(Object, Keyword('camcommitprepared'), Number, Nothing),
    BinaryExpression(Object, Keyword('camconstuctionsetparams'), Array, Nothing),
    BinaryExpression(String, Keyword('camcreate'), Array, Object),
    BinaryExpression(Object, Keyword('cameraeffect'), Array, Nothing),
    BinaryExpression(Object, Keyword('campreload'), Number, Nothing),
    BinaryExpression(Object, Keyword('campreparebank'), Number, Nothing),
    BinaryExpression(Object, Keyword('campreparedir'), Number, Nothing),
    BinaryExpression(Object, Keyword('campreparedive'), Number, Nothing),
    BinaryExpression(Object, Keyword('campreparefocus'), Array, Nothing),
    BinaryExpression(Object, Keyword('campreparefov'), Number, Nothing),
    BinaryExpression(Object, Keyword('campreparefovrange'), Array, Nothing),
    BinaryExpression(Object, Keyword('campreparepos'), Array, Nothing),
    BinaryExpression(Object, Keyword('campreparerelpos'), Array, Nothing),
    BinaryExpression(Object, Keyword('campreparetarget'), Object, Nothing),
    BinaryExpression(Object, Keyword('campreparetarget'), Array, Nothing),
    BinaryExpression(Object, Keyword('camsetbank'), Number, Nothing),
    BinaryExpression(Object, Keyword('camsetdir'), Array, Nothing),
    BinaryExpression(Object, Keyword('camsetdive'), Number, Nothing),
    BinaryExpression(Object, Keyword('camsetfocus'), Array, Nothing),
    BinaryExpression(Object, Keyword('camsetfov'), Number, Nothing),
    BinaryExpression(Object, Keyword('camsetfovrange'), Array, Nothing),
    BinaryExpression(Object, Keyword('camsetpos'), Array, Nothing),
    BinaryExpression(Object, Keyword('camsetrelpos'), Array, Nothing),
    BinaryExpression(Object, Keyword('camsettarget'), Object, Nothing),
    BinaryExpression(Object, Keyword('camsettarget'), Array, Nothing),
    BinaryExpression(Object, Keyword('canadd'), String, Boolean),
    BinaryExpression(Object, Keyword('canadd'), Array, Boolean),
    BinaryExpression(Object, Keyword('canadditemtobackpack'), String, Boolean),
    BinaryExpression(Object, Keyword('canadditemtobackpack'), Array, Boolean),
    BinaryExpression(Object, Keyword('canadditemtouniform'), String, Boolean),
    BinaryExpression(Object, Keyword('canadditemtouniform'), Array, Boolean),
    BinaryExpression(Object, Keyword('canadditemtovest'), String, Boolean),
    BinaryExpression(Object, Keyword('canadditemtovest'), Array, Boolean),
    BinaryExpression(Object, Keyword('canslingload'), Object, Boolean),
    BinaryExpression(Object, Keyword('canvehiclecargo'), Object, Array),
    BinaryExpression(TryType, Keyword('catch'), Code, Anything),
    BinaryExpression(Control, Keyword('cbsetchecked'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('checkvisibility'), Array, Number),
    BinaryExpression(Type, Keyword('clear3denattribute'), String, Nothing),
    BinaryExpression(Display, Keyword('closedisplay'), Number, Nothing),
    BinaryExpression(Object, Keyword('commandartilleryfire'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandartilleryfire'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandchat'), String, Nothing),
    BinaryExpression(Array, Keyword('commandchat'), String, Nothing),
    BinaryExpression(Object, Keyword('commandfire'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandfire'), Object, Nothing),
    BinaryExpression(Object, Keyword('commandfollow'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandfollow'), Object, Nothing),
    BinaryExpression(Object, Keyword('commandfsm'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandfsm'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandmove'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandmove'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandradio'), String, Nothing),
    BinaryExpression(Array, Keyword('commandradio'), String, Nothing),
    BinaryExpression(Object, Keyword('commandsuppressivefire'), Object, Nothing),
    BinaryExpression(Object, Keyword('commandsuppressivefire'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandsuppressivefire'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandsuppressivefire'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandtarget'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandtarget'), Object, Nothing),
    BinaryExpression(Object, Keyword('commandwatch'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandwatch'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandwatch'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandwatch'), Object, Nothing),
    BinaryExpression(String, Keyword('configclasses'), Config, Array),
    BinaryExpression(Object, Keyword('confirmsensortarget'), Array, Nothing),
    BinaryExpression(Object, Keyword('connectterminaltouav'), Object, Boolean),
    BinaryExpression(Control, Keyword('controlsgroupctrl'), Number, Control),
    BinaryExpression(Group, Keyword('copywaypoints'), Group, Nothing),
    BinaryExpression(Code, Keyword('count'), Array, Number),
    BinaryExpression(Object, Keyword('countenemy'), Array, Number),
    BinaryExpression(Object, Keyword('countfriendly'), Array, Number),
    BinaryExpression(Side, Keyword('countside'), Array, Number),
    BinaryExpression(String, Keyword('counttype'), Array, Number),
    BinaryExpression(Object, Keyword('countunknown'), Array, Number),
    BinaryExpression(Group, Keyword('create3denentity'), Array, Anything),
    BinaryExpression(Object, Keyword('creatediaryrecord'), Array, DiaryReport),
    BinaryExpression(Object, Keyword('creatediarysubject'), Array, Number),
    BinaryExpression(Display, Keyword('createdisplay'), String, Display),
    BinaryExpression(Control, Keyword('createmenu'), Number, Nothing),
    BinaryExpression(Display, Keyword('createmissiondisplay'), String, Display),
    BinaryExpression(Display, Keyword('createmissiondisplay'), Array, Display),
    BinaryExpression(Display, Keyword('creatempcampaigndisplay'), String, Nothing),
    BinaryExpression(Object, Keyword('createsimpletask'), Array, Task),
    BinaryExpression(String, Keyword('createsite'), Array, Object),
    BinaryExpression(TeamMember, Keyword('createtask'), Array, Task),
    BinaryExpression(String, Keyword('createunit'), Array, Nothing),
    BinaryExpression(Group, Keyword('createunit'), Array, Object),
    BinaryExpression(String, Keyword('createvehicle'), Array, Object),
    BinaryExpression(String, Keyword('createvehiclelocal'), Array, Object),
    BinaryExpression(Control, Keyword('ctdata'), Number, String),
    BinaryExpression(Control, Keyword('ctfindheaderrows'), Number, Array),
    BinaryExpression(Control, Keyword('ctfindrowheader'), Number, Number),
    BinaryExpression(Control, Keyword('ctheadercontrols'), Number, Array),
    BinaryExpression(Control, Keyword('ctremoveheaders'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctremoverows'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrladdeventhandler'), Array, Number),
    BinaryExpression(Control, Keyword('ctrlchecked'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlcommit'), Number, Nothing),
    BinaryExpression(Display, Keyword('ctrlcreate'), Array, Control),
    BinaryExpression(Control, Keyword('ctrlenable'), Boolean, Nothing),
    BinaryExpression(Control, Keyword('ctrlmapanimadd'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlmapcursor'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlmapscreentoworld'), Array, Array),
    BinaryExpression(Control, Keyword('ctrlmapworldtoscreen'), Array, Array),
    BinaryExpression(Control, Keyword('ctrlremovealleventhandlers'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlremoveeventhandler'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetactivecolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetangle'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetautoscrolldelay'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetautoscrollrewind'), Boolean, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetautoscrollspeed'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetbackgroundcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetchecked'), Boolean, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetchecked'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetdisabledcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlseteventhandler'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfade'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfont'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth1'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth1b'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth2'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth2b'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth3'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth3b'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth4'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth4b'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth5'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth5b'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth6'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfonth6b'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontheight'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontheighth1'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontheighth2'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontheighth3'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontheighth4'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontheighth5'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontheighth6'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontheightsecondary'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontp'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontp'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontpb'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetfontsecondary'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetforegroundcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetmodel'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetmodeldirandup'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetmodelscale'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetposition'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetscale'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctrlsetstructuredtext'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsettext'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsettextcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsettextcolorsecondary'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsettextsecondary'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsettooltip'), String, Nothing),
    BinaryExpression(Control, Keyword('ctrlsettooltipcolorbox'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsettooltipcolorshade'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlsettooltipcolortext'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctrlshow'), Boolean, Nothing),
    BinaryExpression(Control, Keyword('ctrowcontrols'), Number, Array),
    BinaryExpression(Control, Keyword('ctsetcursel'), Number, Nothing),
    BinaryExpression(Control, Keyword('ctsetdata'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctsetheadertemplate'), Config, Nothing),
    BinaryExpression(Control, Keyword('ctsetrowtemplate'), Config, Nothing),
    BinaryExpression(Control, Keyword('ctsetvalue'), Array, Nothing),
    BinaryExpression(Control, Keyword('ctvalue'), Number, Number),
    BinaryExpression(Object, Keyword('curatorcoef'), String, Number),
    BinaryExpression(Object, Keyword('currentmagazinedetailturret'), Array, String),
    BinaryExpression(Object, Keyword('currentmagazineturret'), Array, String),
    BinaryExpression(Object, Keyword('currentweaponturret'), Array, String),
    BinaryExpression(Object, Keyword('customchat'), Array, Nothing),
    BinaryExpression(Object, Keyword('customradio'), Array, Nothing),
    BinaryExpression(String, Keyword('cutfadeout'), Number, Number),
    BinaryExpression(Number, Keyword('cutfadeout'), Number, Nothing),
    BinaryExpression(String, Keyword('cutobj'), Array, Number),
    BinaryExpression(Number, Keyword('cutobj'), Array, Nothing),
    BinaryExpression(String, Keyword('cutrsc'), Array, Number),
    BinaryExpression(Number, Keyword('cutrsc'), Array, Nothing),
    BinaryExpression(String, Keyword('cuttext'), Array, Number),
    BinaryExpression(Number, Keyword('cuttext'), Array, Nothing),
    BinaryExpression(Number, Keyword('debugfsm'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('deleteat'), Number, Anything),
    BinaryExpression(Control, Keyword('deleteeditorobject'), String, Anything),
    BinaryExpression(Group, Keyword('deletegroupwhenempty'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('deleterange'), Array, Nothing),
    BinaryExpression(TeamMember, Keyword('deleteresources'), Array, Nothing),
    BinaryExpression(Object, Keyword('deletevehiclecrew'), Object, Nothing),
    BinaryExpression(Object, Keyword('diarysubjectexists'), String, Boolean),
    BinaryExpression(Object, Keyword('directsay'), String, Nothing),
    BinaryExpression(Object, Keyword('disableai'), String, Nothing),
    BinaryExpression(Object, Keyword('disablecollisionwith'), Object, Nothing),
    BinaryExpression(Object, Keyword('disableconversation'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('disablenvgequipment'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('disabletiequipment'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('disableuavconnectability'), Array, Nothing),
    BinaryExpression(Display, Keyword('displayaddeventhandler'), Array, Number),
    BinaryExpression(Display, Keyword('displayctrl'), Number, Control),
    BinaryExpression(Display, Keyword('displayremovealleventhandlers'), String, Nothing),
    BinaryExpression(Display, Keyword('displayremoveeventhandler'), Array, Nothing),
    BinaryExpression(Display, Keyword('displayseteventhandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('distance'), Object, Number),
    BinaryExpression(Object, Keyword('distance'), Array, Number),
    BinaryExpression(Array, Keyword('distance'), Object, Number),
    BinaryExpression(Array, Keyword('distance'), Array, Number),
    BinaryExpression(Location, Keyword('distance'), Location, Number),
    BinaryExpression(Location, Keyword('distance'), Array, Number),
    BinaryExpression(Array, Keyword('distance'), Location, Number),
    BinaryExpression(Object, Keyword('distance2d'), Object, Number),
    BinaryExpression(Object, Keyword('distance2d'), Array, Number),
    BinaryExpression(Array, Keyword('distance2d'), Object, Number),
    BinaryExpression(Array, Keyword('distance2d'), Array, Number),
    BinaryExpression(Object, Keyword('distancesqr'), Object, Number),
    BinaryExpression(Object, Keyword('distancesqr'), Array, Number),
    BinaryExpression(Array, Keyword('distancesqr'), Object, Number),
    BinaryExpression(Array, Keyword('distancesqr'), Array, Number),
    BinaryExpression(Location, Keyword('distancesqr'), Location, Number),
    BinaryExpression(Location, Keyword('distancesqr'), Array, Number),
    BinaryExpression(Array, Keyword('distancesqr'), Location, Number),
    BinaryExpression(WhileType, Keyword('do'), Code, Nothing),
    BinaryExpression(WithType, Keyword('do'), Code, Nothing),
    BinaryExpression(ForType, Keyword('do'), Code, Anything),
    BinaryExpression(SwitchType, Keyword('do'), Code, Anything),
    BinaryExpression(Object, Keyword('doartilleryfire'), Array, Nothing),
    BinaryExpression(Array, Keyword('doartilleryfire'), Array, Nothing),
    BinaryExpression(Object, Keyword('dofire'), Object, Nothing),
    BinaryExpression(Array, Keyword('dofire'), Object, Nothing),
    BinaryExpression(Object, Keyword('dofollow'), Object, Nothing),
    BinaryExpression(Array, Keyword('dofollow'), Object, Nothing),
    BinaryExpression(Object, Keyword('dofsm'), Array, Nothing),
    BinaryExpression(Array, Keyword('dofsm'), Array, Nothing),
    BinaryExpression(Object, Keyword('domove'), Array, Nothing),
    BinaryExpression(Array, Keyword('domove'), Array, Nothing),
    BinaryExpression(Object, Keyword('doorphase'), String, Number),
    BinaryExpression(Object, Keyword('dosuppressivefire'), Object, Nothing),
    BinaryExpression(Object, Keyword('dosuppressivefire'), Array, Nothing),
    BinaryExpression(Array, Keyword('dosuppressivefire'), Object, Nothing),
    BinaryExpression(Array, Keyword('dosuppressivefire'), Array, Nothing),
    BinaryExpression(Object, Keyword('dotarget'), Object, Nothing),
    BinaryExpression(Array, Keyword('dotarget'), Object, Nothing),
    BinaryExpression(Object, Keyword('dowatch'), Array, Nothing),
    BinaryExpression(Array, Keyword('dowatch'), Array, Nothing),
    BinaryExpression(Object, Keyword('dowatch'), Object, Nothing),
    BinaryExpression(Array, Keyword('dowatch'), Object, Nothing),
    BinaryExpression(Control, Keyword('drawarrow'), Array, Nothing),
    BinaryExpression(Control, Keyword('drawellipse'), Array, Nothing),
    BinaryExpression(Control, Keyword('drawicon'), Array, Nothing),
    BinaryExpression(Control, Keyword('drawline'), Array, Nothing),
    BinaryExpression(Control, Keyword('drawlink'), Array, Nothing),
    BinaryExpression(Control, Keyword('drawlocation'), Location, Nothing),
    BinaryExpression(Control, Keyword('drawpolygon'), Array, Nothing),
    BinaryExpression(Control, Keyword('drawrectangle'), Array, Nothing),
    BinaryExpression(Control, Keyword('drawtriangle'), Array, Nothing),
    BinaryExpression(Control, Keyword('editobject'), String, Anything),
    BinaryExpression(Control, Keyword('editorseteventhandler'), Array, Nothing),
    BinaryExpression(Code, Keyword('else'), Code, Array),
    BinaryExpression(Object, Keyword('emptypositions'), String, Number),
    BinaryExpression(Object, Keyword('enableai'), String, Nothing),
    BinaryExpression(String, Keyword('enableaifeature'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableaimprecision'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableattack'), Boolean, Nothing),
    BinaryExpression(Group, Keyword('enableattack'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableautostartuprtd'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableautotrimrtd'), Boolean, Boolean),
    BinaryExpression(Number, Keyword('enablechannel'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('enablechannel'), Array, Nothing),
    BinaryExpression(Object, Keyword('enablecollisionwith'), Object, Nothing),
    BinaryExpression(Object, Keyword('enablecopilot'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enabledynamicsimulation'), Boolean, Nothing),
    BinaryExpression(Group, Keyword('enabledynamicsimulation'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablefatigue'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablegunlights'), String, Nothing),
    BinaryExpression(Group, Keyword('enablegunlights'), String, Nothing),
    BinaryExpression(Object, Keyword('enableinfopanelcomponent'), Array, Boolean),
    BinaryExpression(Array, Keyword('enableinfopanelcomponent'), Array, Boolean),
    BinaryExpression(Object, Keyword('enableirlasers'), Boolean, Nothing),
    BinaryExpression(Group, Keyword('enableirlasers'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablemimics'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablepersonturret'), Array, Nothing),
    BinaryExpression(Object, Keyword('enablereload'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableropeattach'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablesimulation'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablesimulationglobal'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablestamina'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableuavconnectability'), Array, Nothing),
    BinaryExpression(Object, Keyword('enableuavwaypoints'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablevehiclecargo'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablevehiclesensor'), Array, Nothing),
    BinaryExpression(Object, Keyword('enableweapondisassembly'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('engineon'), Boolean, Nothing),
    BinaryExpression(Control, Keyword('evalobjectargument'), Array, Anything),
    BinaryExpression(Type, Keyword('exec'), String, Nothing),
    BinaryExpression(Control, Keyword('execeditorscript'), Array, Anything),
    BinaryExpression(Type, Keyword('execfsm'), String, Number),
    BinaryExpression(Type, Keyword('execvm'), String, Script),
    BinaryExpression(IfType, Keyword('exitwith'), Code, Anything),
    BinaryExpression(Number, Keyword('fademusic'), Number, Nothing),
    BinaryExpression(Number, Keyword('faderadio'), Number, Nothing),
    BinaryExpression(Number, Keyword('fadesound'), Number, Nothing),
    BinaryExpression(Number, Keyword('fadespeech'), Number, Nothing),
    BinaryExpression(Array, Keyword('find'), Type, Number),
    BinaryExpression(String, Keyword('find'), String, Number),
    BinaryExpression(Object, Keyword('findcover'), Array, Object),
    BinaryExpression(Control, Keyword('findeditorobject'), Array, String),
    BinaryExpression(Control, Keyword('findeditorobject'), Type, String),
    BinaryExpression(Array, Keyword('findemptyposition'), Array, Array),
    BinaryExpression(Array, Keyword('findemptypositionready'), Array, Boolean),
    BinaryExpression(Object, Keyword('findnearestenemy'), Object, Object),
    BinaryExpression(Object, Keyword('findnearestenemy'), Array, Object),
    BinaryExpression(Object, Keyword('fire'), String, Nothing),
    BinaryExpression(Object, Keyword('fire'), Array, Nothing),
    BinaryExpression(Object, Keyword('fireattarget'), Array, Boolean),
    BinaryExpression(Object, Keyword('flyinheight'), Number, Nothing),
    BinaryExpression(Object, Keyword('flyinheightasl'), Array, Nothing),
    BinaryExpression(Object, Keyword('forceadduniform'), String, Nothing),
    BinaryExpression(Object, Keyword('forceflagtexture'), String, Nothing),
    BinaryExpression(Object, Keyword('forcefollowroad'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('forcespeed'), Number, Nothing),
    BinaryExpression(Object, Keyword('forcewalk'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('forceweaponfire'), Array, Nothing),
    BinaryExpression(Code, Keyword('foreach'), Array, Nothing),
    BinaryExpression(Code, Keyword('foreachmember'), TeamMember, Nothing),
    BinaryExpression(Code, Keyword('foreachmemberagent'), TeamMember, Nothing),
    BinaryExpression(Code, Keyword('foreachmemberteam'), TeamMember, Nothing),
    BinaryExpression(Object, Keyword('forgettarget'), Object, Nothing),
    BinaryExpression(Group, Keyword('forgettarget'), Object, Nothing),
    BinaryExpression(ForType, Keyword('from'), Number, ForType),
    BinaryExpression(Object, Keyword('get3denattribute'), String, Array),
    BinaryExpression(Group, Keyword('get3denattribute'), String, Array),
    BinaryExpression(Array, Keyword('get3denattribute'), String, Array),
    BinaryExpression(String, Keyword('get3denattribute'), String, Array),
    BinaryExpression(Number, Keyword('get3denattribute'), String, Array),
    BinaryExpression(String, Keyword('get3denmissionattribute'), String, Anything),
    BinaryExpression(Object, Keyword('getartilleryeta'), Array, Number),
    BinaryExpression(Object, Keyword('getcargoindex'), Object, Number),
    BinaryExpression(Object, Keyword('getcompatiblepylonmagazines'), String, Array),
    BinaryExpression(Object, Keyword('getcompatiblepylonmagazines'), Number, Array),
    BinaryExpression(String, Keyword('getcompatiblepylonmagazines'), String, Array),
    BinaryExpression(String, Keyword('getcompatiblepylonmagazines'), Number, Array),
    BinaryExpression(Object, Keyword('getdir'), Object, Number),
    BinaryExpression(Object, Keyword('getdir'), Array, Number),
    BinaryExpression(Array, Keyword('getdir'), Object, Number),
    BinaryExpression(Array, Keyword('getdir'), Array, Number),
    BinaryExpression(Control, Keyword('geteditorobjectscope'), String, String),
    BinaryExpression(Array, Keyword('getenvsoundcontroller'), String, Number),
    BinaryExpression(Side, Keyword('getfriend'), Side, Number),
    BinaryExpression(Number, Keyword('getfsmvariable'), String, Anything),
    BinaryExpression(Number, Keyword('getfsmvariable'), Array, Anything),
    BinaryExpression(Group, Keyword('getgroupicon'), Number, Array),
    BinaryExpression(Object, Keyword('gethidefrom'), Object, Array),
    BinaryExpression(Object, Keyword('gethit'), String, Number),
    BinaryExpression(Object, Keyword('gethitindex'), Number, Number),
    BinaryExpression(Object, Keyword('gethitpointdamage'), String, Number),
    BinaryExpression(Control, Keyword('getobjectargument'), Array, String),
    BinaryExpression(Control, Keyword('getobjectchildren'), String, Array),
    BinaryExpression(Control, Keyword('getobjectproxy'), String, Object),
    BinaryExpression(Object, Keyword('getpos'), Array, Array),
    BinaryExpression(Array, Keyword('getpos'), Array, Array),
    BinaryExpression(Object, Keyword('getreldir'), Object, Number),
    BinaryExpression(Object, Keyword('getreldir'), Array, Number),
    BinaryExpression(Object, Keyword('getrelpos'), Array, Array),
    BinaryExpression(Object, Keyword('getsoundcontroller'), String, Number),
    BinaryExpression(Object, Keyword('getsoundcontrollerresult'), Config, Number),
    BinaryExpression(Object, Keyword('getspeed'), String, Number),
    BinaryExpression(Object, Keyword('getunittrait'), String, Anything),
    BinaryExpression(Display, Keyword('getvariable'), String, Anything),
    BinaryExpression(Display, Keyword('getvariable'), Array, Anything),
    BinaryExpression(Control, Keyword('getvariable'), String, Anything),
    BinaryExpression(Control, Keyword('getvariable'), Array, Anything),
    BinaryExpression(Object, Keyword('getvariable'), String, Anything),
    BinaryExpression(Object, Keyword('getvariable'), Array, Anything),
    BinaryExpression(Group, Keyword('getvariable'), String, Anything),
    BinaryExpression(Group, Keyword('getvariable'), Array, Anything),
    BinaryExpression(Namespace, Keyword('getvariable'), String, Anything),
    BinaryExpression(Namespace, Keyword('getvariable'), Array, Anything),
    BinaryExpression(TeamMember, Keyword('getvariable'), String, Anything),
    BinaryExpression(TeamMember, Keyword('getvariable'), Array, Anything),
    BinaryExpression(Task, Keyword('getvariable'), String, Anything),
    BinaryExpression(Task, Keyword('getvariable'), Array, Anything),
    BinaryExpression(Location, Keyword('getvariable'), String, Anything),
    BinaryExpression(Location, Keyword('getvariable'), Array, Anything),
    BinaryExpression(Object, Keyword('glanceat'), Object, Nothing),
    BinaryExpression(Object, Keyword('glanceat'), Array, Nothing),
    BinaryExpression(Array, Keyword('glanceat'), Object, Nothing),
    BinaryExpression(Array, Keyword('glanceat'), Array, Nothing),
    BinaryExpression(Object, Keyword('globalchat'), String, Nothing),
    BinaryExpression(Object, Keyword('globalradio'), String, Nothing),
    BinaryExpression(Object, Keyword('groupchat'), String, Nothing),
    BinaryExpression(Object, Keyword('groupradio'), String, Nothing),
    BinaryExpression(Object, Keyword('groupselectunit'), Array, Nothing),
    BinaryExpression(Object, Keyword('hasweapon'), String, Boolean),
    BinaryExpression(Object, Keyword('hcgroupparams'), Group, Array),
    BinaryExpression(Object, Keyword('hcremovegroup'), Group, Nothing),
    BinaryExpression(Object, Keyword('hcselectgroup'), Array, Nothing),
    BinaryExpression(Object, Keyword('hcsetgroup'), Array, Nothing),
    BinaryExpression(Object, Keyword('hideobject'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('hideobjectglobal'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('hideselection'), Array, Nothing),
    BinaryExpression(String, Keyword('hintc'), String, Nothing),
    BinaryExpression(String, Keyword('hintc'), String, Nothing),
    BinaryExpression(String, Keyword('hintc'), Array, Nothing),
    BinaryExpression(Control, Keyword('htmlload'), String, Nothing),
    BinaryExpression(Type, Keyword('in'), Array, Boolean),
    BinaryExpression(Object, Keyword('in'), Object, Boolean),
    BinaryExpression(Array, Keyword('in'), Location, Boolean),
    BinaryExpression(Object, Keyword('inarea'), Object, Boolean),
    BinaryExpression(Array, Keyword('inarea'), Object, Boolean),
    BinaryExpression(Object, Keyword('inarea'), String, Boolean),
    BinaryExpression(Array, Keyword('inarea'), String, Boolean),
    BinaryExpression(Object, Keyword('inarea'), Array, Boolean),
    BinaryExpression(Array, Keyword('inarea'), Array, Boolean),
    BinaryExpression(Object, Keyword('inarea'), Location, Boolean),
    BinaryExpression(Array, Keyword('inarea'), Location, Boolean),
    BinaryExpression(Array, Keyword('inareaarray'), Object, Array),
    BinaryExpression(Array, Keyword('inareaarray'), String, Array),
    BinaryExpression(Array, Keyword('inareaarray'), Array, Array),
    BinaryExpression(Array, Keyword('inareaarray'), Location, Array),
    BinaryExpression(Object, Keyword('inflame'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('infopanelcomponentenabled'), Array, Boolean),
    BinaryExpression(Array, Keyword('infopanelcomponentenabled'), Array, Boolean),
    BinaryExpression(Object, Keyword('infopanelcomponents'), String, Array),
    BinaryExpression(Array, Keyword('infopanelcomponents'), String, Array),
    BinaryExpression(Array, Keyword('inpolygon'), Array, Boolean),
    BinaryExpression(Array, Keyword('inrangeofartillery'), Array, Boolean),
    BinaryExpression(Control, Keyword('inserteditorobject'), Array, String),
    BinaryExpression(Array, Keyword('intersect'), Array, Array),
    BinaryExpression(Type, Keyword('isequalto'), Type, Boolean),
    BinaryExpression(Type, Keyword('isequaltype'), Type, Boolean),
    BinaryExpression(Array, Keyword('isequaltypeall'), Type, Boolean),
    BinaryExpression(Type, Keyword('isequaltypeany'), Array, Boolean),
    BinaryExpression(Array, Keyword('isequaltypearray'), Array, Boolean),
    BinaryExpression(Type, Keyword('isequaltypeparams'), Array, Boolean),
    BinaryExpression(Object, Keyword('isflashlighton'), String, Boolean),
    BinaryExpression(Array, Keyword('isflatempty'), Array, Array),
    BinaryExpression(Object, Keyword('isirlaseron'), String, Boolean),
    BinaryExpression(String, Keyword('iskindof'), String, Boolean),
    BinaryExpression(String, Keyword('iskindof'), Array, Boolean),
    BinaryExpression(Object, Keyword('iskindof'), String, Boolean),
    BinaryExpression(Object, Keyword('issensortargetconfirmed'), Side, Boolean),
    BinaryExpression(Object, Keyword('isuavconnectable'), Array, Boolean),
    BinaryExpression(Object, Keyword('isuniformallowed'), String, Boolean),
    BinaryExpression(Object, Keyword('isvehiclesensorenabled'), String, Array),
    BinaryExpression(Array, Keyword('join'), Object, Nothing),
    BinaryExpression(Array, Keyword('join'), Group, Nothing),
    BinaryExpression(Object, Keyword('joinas'), Array, Nothing),
    BinaryExpression(Object, Keyword('joinassilent'), Array, Nothing),
    BinaryExpression(Array, Keyword('joinsilent'), Object, Nothing),
    BinaryExpression(Array, Keyword('joinsilent'), Group, Nothing),
    BinaryExpression(Array, Keyword('joinstring'), String, String),
    BinaryExpression(Object, Keyword('kbadddatabase'), String, Boolean),
    BinaryExpression(Object, Keyword('kbadddatabasetargets'), String, Boolean),
    BinaryExpression(Object, Keyword('kbaddtopic'), Array, Nothing),
    BinaryExpression(Object, Keyword('kbhastopic'), String, Boolean),
    BinaryExpression(Object, Keyword('kbreact'), Array, Nothing),
    BinaryExpression(Object, Keyword('kbremovetopic'), String, Nothing),
    BinaryExpression(Object, Keyword('kbtell'), Array, Nothing),
    BinaryExpression(Object, Keyword('kbwassaid'), Array, Boolean),
    BinaryExpression(Object, Keyword('knowsabout'), Object, Number),
    BinaryExpression(Group, Keyword('knowsabout'), Object, Number),
    BinaryExpression(Side, Keyword('knowsabout'), Object, Number),
    BinaryExpression(Object, Keyword('land'), String, Nothing),
    BinaryExpression(Object, Keyword('landat'), Object, Nothing),
    BinaryExpression(Object, Keyword('landat'), Number, Nothing),
    BinaryExpression(Control, Keyword('lbadd'), String, Number),
    BinaryExpression(Control, Keyword('lbcolor'), Number, Array),
    BinaryExpression(Control, Keyword('lbcolorright'), Number, Array),
    BinaryExpression(Control, Keyword('lbdata'), Number, String),
    BinaryExpression(Control, Keyword('lbdelete'), Number, Nothing),
    BinaryExpression(Control, Keyword('lbisselected'), Number, Boolean),
    BinaryExpression(Control, Keyword('lbpicture'), Number, String),
    BinaryExpression(Control, Keyword('lbpictureright'), Number, String),
    BinaryExpression(Control, Keyword('lbsetcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetcolorright'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetcursel'), Number, Nothing),
    BinaryExpression(Control, Keyword('lbsetdata'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetpicture'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetpicturecolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetpicturecolordisabled'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetpicturecolorselected'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetpictureright'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetpicturerightcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetpicturerightcolordisabled'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetpicturerightcolorselected'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetselectcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetselectcolorright'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetselected'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsettext'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsettextright'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsettooltip'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbsetvalue'), Array, Nothing),
    BinaryExpression(Control, Keyword('lbtext'), Number, String),
    BinaryExpression(Control, Keyword('lbtextright'), Number, String),
    BinaryExpression(Control, Keyword('lbvalue'), Number, Number),
    BinaryExpression(Object, Keyword('leavevehicle'), Object, Nothing),
    BinaryExpression(Group, Keyword('leavevehicle'), Object, Nothing),
    BinaryExpression(Object, Keyword('lightattachobject'), Array, Nothing),
    BinaryExpression(Object, Keyword('limitspeed'), Number, Nothing),
    BinaryExpression(Object, Keyword('linkitem'), String, Nothing),
    BinaryExpression(Control, Keyword('listobjects'), String, Array),
    BinaryExpression(Control, Keyword('lnbaddcolumn'), Number, Number),
    BinaryExpression(Control, Keyword('lnbaddrow'), Array, Number),
    BinaryExpression(Control, Keyword('lnbcolor'), Array, Array),
    BinaryExpression(Control, Keyword('lnbcolorright'), Array, Array),
    BinaryExpression(Control, Keyword('lnbdata'), Array, String),
    BinaryExpression(Control, Keyword('lnbdeletecolumn'), Number, Nothing),
    BinaryExpression(Control, Keyword('lnbdeleterow'), Number, Nothing),
    BinaryExpression(Control, Keyword('lnbpicture'), Array, String),
    BinaryExpression(Control, Keyword('lnbpictureright'), Array, String),
    BinaryExpression(Control, Keyword('lnbsetcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetcolorright'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetcolumnspos'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetcurselrow'), Number, Nothing),
    BinaryExpression(Control, Keyword('lnbsetdata'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetpicture'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetpicturecolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetpicturecolorright'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetpicturecolorselected'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetpicturecolorselectedright'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetpictureright'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsettext'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsettextright'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsetvalue'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsort'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbsortbyvalue'), Array, Nothing),
    BinaryExpression(Control, Keyword('lnbtext'), Array, String),
    BinaryExpression(Control, Keyword('lnbtextright'), Array, String),
    BinaryExpression(Control, Keyword('lnbvalue'), Array, Number),
    BinaryExpression(Object, Keyword('loadidentity'), String, Boolean),
    BinaryExpression(Object, Keyword('loadmagazine'), Array, Nothing),
    BinaryExpression(Control, Keyword('loadoverlay'), Config, Nothing),
    BinaryExpression(Object, Keyword('loadstatus'), String, Boolean),
    BinaryExpression(Object, Keyword('lock'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('lock'), Number, Nothing),
    BinaryExpression(Object, Keyword('lockcamerato'), Array, Nothing),
    BinaryExpression(Object, Keyword('lockcargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('lockcargo'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('lockdriver'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('lockedcargo'), Number, Boolean),
    BinaryExpression(Object, Keyword('lockedturret'), Array, Boolean),
    BinaryExpression(Object, Keyword('lockturret'), Array, Nothing),
    BinaryExpression(Object, Keyword('lockwp'), Boolean, Nothing),
    BinaryExpression(Group, Keyword('lockwp'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('lookat'), Object, Nothing),
    BinaryExpression(Object, Keyword('lookat'), Array, Nothing),
    BinaryExpression(Array, Keyword('lookat'), Object, Nothing),
    BinaryExpression(Array, Keyword('lookat'), Array, Nothing),
    BinaryExpression(Control, Keyword('lookatpos'), Array, Nothing),
    BinaryExpression(Object, Keyword('magazinesturret'), Array, Array),
    BinaryExpression(Object, Keyword('magazineturretammo'), Array, Number),
    BinaryExpression(Control, Keyword('mapcenteroncamera'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('max'), Number, Number),
    BinaryExpression(Control, Keyword('menuaction'), Array, String),
    BinaryExpression(Control, Keyword('menuadd'), Array, Number),
    BinaryExpression(Control, Keyword('menuchecked'), Array, Boolean),
    BinaryExpression(Control, Keyword('menucollapse'), Array, Nothing),
    BinaryExpression(Control, Keyword('menudata'), Array, String),
    BinaryExpression(Control, Keyword('menudelete'), Array, Nothing),
    BinaryExpression(Control, Keyword('menuenable'), Array, Nothing),
    BinaryExpression(Control, Keyword('menuenabled'), Array, Boolean),
    BinaryExpression(Control, Keyword('menuexpand'), Array, Nothing),
    BinaryExpression(Control, Keyword('menupicture'), Array, String),
    BinaryExpression(Control, Keyword('menusetaction'), Array, Nothing),
    BinaryExpression(Control, Keyword('menusetcheck'), Array, Nothing),
    BinaryExpression(Control, Keyword('menusetdata'), Array, Nothing),
    BinaryExpression(Control, Keyword('menusetpicture'), Array, Nothing),
    BinaryExpression(Control, Keyword('menusetvalue'), Array, Nothing),
    BinaryExpression(Control, Keyword('menushortcut'), Array, Number),
    BinaryExpression(Control, Keyword('menushortcuttext'), Array, String),
    BinaryExpression(Control, Keyword('menusize'), Array, Number),
    BinaryExpression(Control, Keyword('menusort'), Array, Nothing),
    BinaryExpression(Control, Keyword('menutext'), Array, String),
    BinaryExpression(Control, Keyword('menuurl'), Array, String),
    BinaryExpression(Control, Keyword('menuvalue'), Array, Number),
    BinaryExpression(Number, Keyword('min'), Number, Number),
    BinaryExpression(Object, Keyword('minedetectedby'), Side, Boolean),
    BinaryExpression(Number, Keyword('mod'), Number, Number),
    BinaryExpression(Object, Keyword('modeltoworld'), Array, Array),
    BinaryExpression(Object, Keyword('modeltoworldvisual'), Array, Array),
    BinaryExpression(Object, Keyword('modeltoworldvisualworld'), Array, Array),
    BinaryExpression(Object, Keyword('modeltoworldworld'), Array, Array),
    BinaryExpression(Object, Keyword('move'), Array, Nothing),
    BinaryExpression(Group, Keyword('move'), Array, Nothing),
    BinaryExpression(Object, Keyword('moveinany'), Object, Boolean),
    BinaryExpression(Object, Keyword('moveincargo'), Object, Nothing),
    BinaryExpression(Object, Keyword('moveincargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('moveincommander'), Object, Nothing),
    BinaryExpression(Object, Keyword('moveindriver'), Object, Nothing),
    BinaryExpression(Object, Keyword('moveingunner'), Object, Nothing),
    BinaryExpression(Object, Keyword('moveinturret'), Array, Nothing),
    BinaryExpression(Control, Keyword('moveobjecttoend'), String, Nothing),
    BinaryExpression(Object, Keyword('moveto'), Array, Nothing),
    BinaryExpression(Object, Keyword('nearentities'), Number, Array),
    BinaryExpression(Object, Keyword('nearentities'), Array, Array),
    BinaryExpression(Array, Keyword('nearentities'), Number, Array),
    BinaryExpression(Array, Keyword('nearentities'), Array, Array),
    BinaryExpression(Array, Keyword('nearestobject'), String, Object),
    BinaryExpression(Array, Keyword('nearestobject'), Number, Object),
    BinaryExpression(Object, Keyword('nearobjects'), Number, Array),
    BinaryExpression(Object, Keyword('nearobjects'), Array, Array),
    BinaryExpression(Array, Keyword('nearobjects'), Number, Array),
    BinaryExpression(Array, Keyword('nearobjects'), Array, Array),
    BinaryExpression(Object, Keyword('nearobjectsready'), Number, Boolean),
    BinaryExpression(Array, Keyword('nearobjectsready'), Number, Boolean),
    BinaryExpression(Object, Keyword('nearroads'), Number, Array),
    BinaryExpression(Array, Keyword('nearroads'), Number, Array),
    BinaryExpression(Object, Keyword('nearsupplies'), Number, Array),
    BinaryExpression(Object, Keyword('nearsupplies'), Array, Array),
    BinaryExpression(Array, Keyword('nearsupplies'), Number, Array),
    BinaryExpression(Array, Keyword('nearsupplies'), Array, Array),
    BinaryExpression(Object, Keyword('neartargets'), Number, Array),
    BinaryExpression(Control, Keyword('newoverlay'), Config, Nothing),
    BinaryExpression(Control, Keyword('nmenuitems'), String, Number),
    BinaryExpression(Control, Keyword('nmenuitems'), Number, Number),
    BinaryExpression(String, Keyword('objstatus'), String, Nothing),
    BinaryExpression(Control, Keyword('ondoubleclick'), String, Anything),
    BinaryExpression(Type, Keyword('onmapsingleclick'), Code, Nothing),
    BinaryExpression(Type, Keyword('onmapsingleclick'), String, Nothing),
    BinaryExpression(Control, Keyword('onshownewobject'), String, Anything),
    BinaryExpression(Boolean, Keyword('or'), Boolean, Boolean),
    BinaryExpression(Boolean, Keyword('or'), Code, Boolean),
    BinaryExpression(Array, Keyword('ordergetin'), Boolean, Nothing),
    BinaryExpression(Type, Keyword('param'), Array, Anything),
    BinaryExpression(Type, Keyword('params'), Array, Boolean),
    BinaryExpression(Object, Keyword('playaction'), String, Nothing),
    BinaryExpression(Object, Keyword('playactionnow'), String, Nothing),
    BinaryExpression(Object, Keyword('playgesture'), String, Nothing),
    BinaryExpression(Object, Keyword('playmove'), String, Nothing),
    BinaryExpression(Object, Keyword('playmovenow'), String, Nothing),
    BinaryExpression(Control, Keyword('posscreentoworld'), Array, Array),
    BinaryExpression(Control, Keyword('posworldtoscreen'), Array, Array),
    BinaryExpression(String, Keyword('ppeffectadjust'), Array, Nothing),
    BinaryExpression(Number, Keyword('ppeffectadjust'), Array, Nothing),
    BinaryExpression(String, Keyword('ppeffectcommit'), Number, Nothing),
    BinaryExpression(Number, Keyword('ppeffectcommit'), Number, Nothing),
    BinaryExpression(Array, Keyword('ppeffectcommit'), Number, Nothing),
    BinaryExpression(String, Keyword('ppeffectenable'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('ppeffectenable'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('ppeffectenable'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('ppeffectforceinnvg'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('preloadobject'), Object, Boolean),
    BinaryExpression(Number, Keyword('preloadobject'), String, Boolean),
    BinaryExpression(Control, Keyword('progresssetposition'), Number, Nothing),
    BinaryExpression(Number, Keyword('publicvariableclient'), String, Nothing),
    BinaryExpression(Array, Keyword('pushback'), Type, Number),
    BinaryExpression(Array, Keyword('pushbackunique'), Type, Number),
    BinaryExpression(Number, Keyword('radiochanneladd'), Array, Nothing),
    BinaryExpression(Number, Keyword('radiochannelremove'), Array, Nothing),
    BinaryExpression(Number, Keyword('radiochannelsetcallsign'), String, Nothing),
    BinaryExpression(Number, Keyword('radiochannelsetlabel'), String, Nothing),
    BinaryExpression(Number, Keyword('random'), Number, Number),
    BinaryExpression(Number, Keyword('random'), Array, Number),
    BinaryExpression(TeamMember, Keyword('registertask'), String, Boolean),
    BinaryExpression(Object, Keyword('remotecontrol'), Object, Nothing),
    BinaryExpression(Type, Keyword('remoteexec'), Array, Anything),
    BinaryExpression(Type, Keyword('remoteexeccall'), Array, Anything),
    BinaryExpression(Object, Keyword('removeaction'), Number, Nothing),
    BinaryExpression(Object, Keyword('removealleventhandlers'), String, Nothing),
    BinaryExpression(Object, Keyword('removeallmpeventhandlers'), String, Nothing),
    BinaryExpression(Object, Keyword('removecuratoraddons'), Array, Nothing),
    BinaryExpression(Object, Keyword('removecuratorcameraarea'), Number, Nothing),
    BinaryExpression(Object, Keyword('removecuratoreditableobjects'), Array, Nothing),
    BinaryExpression(Object, Keyword('removecuratoreditingarea'), Number, Nothing),
    BinaryExpression(Control, Keyword('removedrawicon'), Array, Nothing),
    BinaryExpression(Control, Keyword('removedrawlinks'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeeventhandler'), Array, Nothing),
    BinaryExpression(Group, Keyword('removegroupicon'), Number, Nothing),
    BinaryExpression(Object, Keyword('removehandgunitem'), String, Nothing),
    BinaryExpression(Object, Keyword('removeitem'), String, Nothing),
    BinaryExpression(Object, Keyword('removeitemfrombackpack'), String, Nothing),
    BinaryExpression(Object, Keyword('removeitemfromuniform'), String, Nothing),
    BinaryExpression(Object, Keyword('removeitemfromvest'), String, Nothing),
    BinaryExpression(Object, Keyword('removeitems'), String, Nothing),
    BinaryExpression(Object, Keyword('removemagazine'), String, Nothing),
    BinaryExpression(Object, Keyword('removemagazine'), Array, Nothing),
    BinaryExpression(Object, Keyword('removemagazineglobal'), String, Nothing),
    BinaryExpression(Object, Keyword('removemagazines'), String, Nothing),
    BinaryExpression(Object, Keyword('removemagazinesturret'), Array, Nothing),
    BinaryExpression(Object, Keyword('removemagazineturret'), Array, Nothing),
    BinaryExpression(Control, Keyword('removemenuitem'), Number, Nothing),
    BinaryExpression(Control, Keyword('removemenuitem'), String, Nothing),
    BinaryExpression(Object, Keyword('removempeventhandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeownedmine'), Object, Nothing),
    BinaryExpression(Object, Keyword('removeprimaryweaponitem'), String, Nothing),
    BinaryExpression(Object, Keyword('removesecondaryweaponitem'), String, Nothing),
    BinaryExpression(Object, Keyword('removesimpletask'), Task, Nothing),
    BinaryExpression(TeamMember, Keyword('removeteammember'), TeamMember, Nothing),
    BinaryExpression(Object, Keyword('removeweapon'), String, Nothing),
    BinaryExpression(Object, Keyword('removeweaponattachmentcargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeweaponcargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeweaponglobal'), String, Nothing),
    BinaryExpression(Object, Keyword('removeweaponturret'), Array, Nothing),
    BinaryExpression(Side, Keyword('reportremotetarget'), Array, Nothing),
    BinaryExpression(Array, Keyword('resize'), Number, Nothing),
    BinaryExpression(Object, Keyword('respawnvehicle'), Array, Nothing),
    BinaryExpression(Object, Keyword('reveal'), Object, Nothing),
    BinaryExpression(Group, Keyword('reveal'), Object, Nothing),
    BinaryExpression(Object, Keyword('reveal'), Array, Nothing),
    BinaryExpression(Group, Keyword('reveal'), Array, Nothing),
    BinaryExpression(Side, Keyword('revealmine'), Object, Nothing),
    BinaryExpression(Array, Keyword('ropeattachto'), Object, Nothing),
    BinaryExpression(Object, Keyword('ropedetach'), Object, Nothing),
    BinaryExpression(Object, Keyword('saveidentity'), String, Boolean),
    BinaryExpression(Object, Keyword('savestatus'), String, Boolean),
    BinaryExpression(Object, Keyword('say'), String, Nothing),
    BinaryExpression(Array, Keyword('say'), String, Nothing),
    BinaryExpression(Object, Keyword('say'), Array, Nothing),
    BinaryExpression(Array, Keyword('say'), Array, Nothing),
    BinaryExpression(Object, Keyword('say2d'), String, Nothing),
    BinaryExpression(Array, Keyword('say2d'), String, Nothing),
    BinaryExpression(Object, Keyword('say2d'), Array, Nothing),
    BinaryExpression(Array, Keyword('say2d'), Array, Nothing),
    BinaryExpression(Object, Keyword('say3d'), String, Nothing),
    BinaryExpression(Array, Keyword('say3d'), String, Nothing),
    BinaryExpression(Object, Keyword('say3d'), Array, Nothing),
    BinaryExpression(Array, Keyword('say3d'), Array, Nothing),
    BinaryExpression(Array, Keyword('select'), Number, Anything),
    BinaryExpression(Array, Keyword('select'), Boolean, Anything),
    BinaryExpression(Array, Keyword('select'), Array, Array),
    BinaryExpression(String, Keyword('select'), Array, String),
    BinaryExpression(Array, Keyword('select'), Code, Array),
    BinaryExpression(Config, Keyword('select'), Number, Config),
    BinaryExpression(Object, Keyword('selectdiarysubject'), String, Nothing),
    BinaryExpression(Control, Keyword('selecteditorobject'), String, Anything),
    BinaryExpression(Object, Keyword('selectionposition'), String, Array),
    BinaryExpression(Object, Keyword('selectionposition'), Array, Array),
    BinaryExpression(Group, Keyword('selectleader'), Object, Nothing),
    BinaryExpression(Array, Keyword('selectrandomweighted'), Array, Anything),
    BinaryExpression(Object, Keyword('selectweapon'), String, Nothing),
    BinaryExpression(Object, Keyword('selectweaponturret'), Array, Nothing),
    BinaryExpression(Object, Keyword('sendsimplecommand'), String, Nothing),
    BinaryExpression(TeamMember, Keyword('sendtask'), Array, Task),
    BinaryExpression(Task, Keyword('sendtaskresult'), Array, Nothing),
    BinaryExpression(String, Keyword('servercommand'), String, Boolean),
    BinaryExpression(Array, Keyword('set'), Array, Nothing),
    BinaryExpression(Type, Keyword('set3denattribute'), Array, Boolean),
    BinaryExpression(Type, Keyword('set3denlayer'), Number, Boolean),
    BinaryExpression(Array, Keyword('set3denlogictype'), String, Nothing),
    BinaryExpression(String, Keyword('set3denmissionattribute'), Array, Nothing),
    BinaryExpression(Array, Keyword('set3denobjecttype'), String, Nothing),
    BinaryExpression(Object, Keyword('setactualcollectivertd'), Number, Nothing),
    BinaryExpression(Object, Keyword('setairplanethrottle'), Number, Nothing),
    BinaryExpression(Object, Keyword('setairportside'), Side, Nothing),
    BinaryExpression(Number, Keyword('setairportside'), Side, Nothing),
    BinaryExpression(Object, Keyword('setammo'), Array, Nothing),
    BinaryExpression(Object, Keyword('setammocargo'), Number, Nothing),
    BinaryExpression(Object, Keyword('setammoonpylon'), Array, Nothing),
    BinaryExpression(Object, Keyword('setanimspeedcoef'), Number, Nothing),
    BinaryExpression(String, Keyword('setattributes'), Array, String),
    BinaryExpression(String, Keyword('setattributes'), Array, String),
    BinaryExpression(Object, Keyword('setautonomous'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setbehaviour'), String, Nothing),
    BinaryExpression(Group, Keyword('setbehaviour'), String, Nothing),
    BinaryExpression(Object, Keyword('setbleedingremaining'), Number, Nothing),
    BinaryExpression(Object, Keyword('setbrakesrtd'), Array, Nothing),
    BinaryExpression(Object, Keyword('setcamerainterest'), Number, Nothing),
    BinaryExpression(Boolean, Keyword('setcamuseti'), Number, Nothing),
    BinaryExpression(Object, Keyword('setcaptive'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setcaptive'), Number, Nothing),
    BinaryExpression(Object, Keyword('setcenterofmass'), Array, Nothing),
    BinaryExpression(Object, Keyword('setcollisionlight'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setcombatmode'), String, Nothing),
    BinaryExpression(Group, Keyword('setcombatmode'), String, Nothing),
    BinaryExpression(TeamMember, Keyword('setcombatmode'), String, Nothing),
    BinaryExpression(Object, Keyword('setconvoyseparation'), Number, Nothing),
    BinaryExpression(Object, Keyword('setcuratorcameraareaceiling'), Number, Nothing),
    BinaryExpression(Object, Keyword('setcuratorcoef'), Array, Nothing),
    BinaryExpression(Object, Keyword('setcuratoreditingareatype'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setcuratorwaypointcost'), Number, Nothing),
    BinaryExpression(Object, Keyword('setcurrenttask'), Task, Nothing),
    BinaryExpression(Group, Keyword('setcurrentwaypoint'), Array, Nothing),
    BinaryExpression(Object, Keyword('setcustomaimcoef'), Number, Nothing),
    BinaryExpression(Object, Keyword('setcustomweightrtd'), Number, Nothing),
    BinaryExpression(Object, Keyword('setdamage'), Number, Nothing),
    BinaryExpression(Object, Keyword('setdamage'), Array, Nothing),
    BinaryExpression(Object, Keyword('setdammage'), Number, Nothing),
    BinaryExpression(String, Keyword('setdebriefingtext'), Array, Nothing),
    BinaryExpression(Object, Keyword('setdestination'), Array, Nothing),
    BinaryExpression(Object, Keyword('setdir'), Number, Nothing),
    BinaryExpression(Location, Keyword('setdirection'), Number, Nothing),
    BinaryExpression(Control, Keyword('setdrawicon'), Array, Nothing),
    BinaryExpression(Object, Keyword('setdriveonpath'), Array, Nothing),
    BinaryExpression(Object, Keyword('setdropinterval'), Number, Nothing),
    BinaryExpression(String, Keyword('setdynamicsimulationdistance'), Number, Nothing),
    BinaryExpression(String, Keyword('setdynamicsimulationdistancecoef'), Number, Nothing),
    BinaryExpression(Control, Keyword('seteditormode'), String, Nothing),
    BinaryExpression(Control, Keyword('seteditorobjectscope'), Array, Nothing),
    BinaryExpression(Object, Keyword('seteffectcondition'), String, Nothing),
    BinaryExpression(Array, Keyword('seteffectcondition'), String, Nothing),
    BinaryExpression(Object, Keyword('setenginerpmrtd'), Array, Nothing),
    BinaryExpression(Object, Keyword('setface'), String, Nothing),
    BinaryExpression(Object, Keyword('setfaceanimation'), Number, Nothing),
    BinaryExpression(Object, Keyword('setfatigue'), Number, Nothing),
    BinaryExpression(Object, Keyword('setfeaturetype'), Number, Boolean),
    BinaryExpression(Object, Keyword('setflaganimationphase'), Number, Nothing),
    BinaryExpression(Object, Keyword('setflagowner'), Object, Nothing),
    BinaryExpression(Object, Keyword('setflagside'), Side, Nothing),
    BinaryExpression(Object, Keyword('setflagtexture'), String, Nothing),
    BinaryExpression(Number, Keyword('setfog'), Number, Nothing),
    BinaryExpression(Number, Keyword('setfog'), Array, Nothing),
    BinaryExpression(Number, Keyword('setforcegeneratorrtd'), Array, Nothing),
    BinaryExpression(Object, Keyword('setformation'), String, Nothing),
    BinaryExpression(Group, Keyword('setformation'), String, Nothing),
    BinaryExpression(TeamMember, Keyword('setformation'), String, Nothing),
    BinaryExpression(Object, Keyword('setformationtask'), String, Nothing),
    BinaryExpression(Object, Keyword('setformdir'), Number, Nothing),
    BinaryExpression(Group, Keyword('setformdir'), Number, Nothing),
    BinaryExpression(Side, Keyword('setfriend'), Array, Nothing),
    BinaryExpression(TeamMember, Keyword('setfromeditor'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('setfsmvariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setfuel'), Number, Nothing),
    BinaryExpression(Object, Keyword('setfuelcargo'), Number, Nothing),
    BinaryExpression(Group, Keyword('setgroupicon'), Array, Nothing),
    BinaryExpression(Group, Keyword('setgroupiconparams'), Array, Nothing),
    BinaryExpression(Object, Keyword('setgroupid'), Array, Nothing),
    BinaryExpression(Group, Keyword('setgroupid'), Array, Nothing),
    BinaryExpression(Object, Keyword('setgroupidglobal'), Array, Nothing),
    BinaryExpression(Group, Keyword('setgroupidglobal'), Array, Nothing),
    BinaryExpression(Group, Keyword('setgroupowner'), Number, Boolean),
    BinaryExpression(Number, Keyword('setgusts'), Number, Nothing),
    BinaryExpression(Object, Keyword('sethidebehind'), Array, Nothing),
    BinaryExpression(Object, Keyword('sethit'), Array, Nothing),
    BinaryExpression(Object, Keyword('sethitindex'), Array, Nothing),
    BinaryExpression(Object, Keyword('sethitpointdamage'), Array, Nothing),
    BinaryExpression(Object, Keyword('setidentity'), String, Nothing),
    BinaryExpression(Location, Keyword('setimportance'), Number, Nothing),
    BinaryExpression(TeamMember, Keyword('setleader'), TeamMember, Nothing),
    BinaryExpression(Object, Keyword('setlightambient'), Array, Nothing),
    BinaryExpression(Object, Keyword('setlightattenuation'), Array, Nothing),
    BinaryExpression(Object, Keyword('setlightbrightness'), Number, Nothing),
    BinaryExpression(Object, Keyword('setlightcolor'), Array, Nothing),
    BinaryExpression(Object, Keyword('setlightdaylight'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setlightflaremaxdistance'), Number, Nothing),
    BinaryExpression(Object, Keyword('setlightflaresize'), Number, Nothing),
    BinaryExpression(Object, Keyword('setlightintensity'), Number, Nothing),
    BinaryExpression(Number, Keyword('setlightnings'), Number, Nothing),
    BinaryExpression(Object, Keyword('setlightuseflare'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setmagazineturretammo'), Array, Nothing),
    BinaryExpression(String, Keyword('setmarkeralpha'), Number, Nothing),
    BinaryExpression(String, Keyword('setmarkeralphalocal'), Number, Nothing),
    BinaryExpression(String, Keyword('setmarkerbrush'), String, Nothing),
    BinaryExpression(String, Keyword('setmarkerbrushlocal'), String, Nothing),
    BinaryExpression(String, Keyword('setmarkercolor'), String, Nothing),
    BinaryExpression(String, Keyword('setmarkercolorlocal'), String, Nothing),
    BinaryExpression(String, Keyword('setmarkerdir'), Number, Nothing),
    BinaryExpression(String, Keyword('setmarkerdirlocal'), Number, Nothing),
    BinaryExpression(String, Keyword('setmarkerpos'), Array, Nothing),
    BinaryExpression(String, Keyword('setmarkerposlocal'), Array, Nothing),
    BinaryExpression(String, Keyword('setmarkershape'), String, Nothing),
    BinaryExpression(String, Keyword('setmarkershapelocal'), String, Nothing),
    BinaryExpression(String, Keyword('setmarkersize'), Array, Nothing),
    BinaryExpression(String, Keyword('setmarkersizelocal'), Array, Nothing),
    BinaryExpression(String, Keyword('setmarkertext'), String, Nothing),
    BinaryExpression(String, Keyword('setmarkertextlocal'), String, Nothing),
    BinaryExpression(String, Keyword('setmarkertype'), String, Nothing),
    BinaryExpression(String, Keyword('setmarkertypelocal'), String, Nothing),
    BinaryExpression(Object, Keyword('setmass'), Number, Nothing),
    BinaryExpression(Object, Keyword('setmass'), Array, Nothing),
    BinaryExpression(Object, Keyword('setmimic'), String, Nothing),
    BinaryExpression(Object, Keyword('setmusiceffect'), String, Nothing),
    BinaryExpression(Array, Keyword('setmusiceffect'), String, Nothing),
    BinaryExpression(Object, Keyword('setname'), String, Nothing),
    BinaryExpression(Object, Keyword('setname'), Array, Nothing),
    BinaryExpression(Location, Keyword('setname'), String, Nothing),
    BinaryExpression(Object, Keyword('setnamesound'), String, Nothing),
    BinaryExpression(Control, Keyword('setobjectarguments'), Array, Anything),
    BinaryExpression(Object, Keyword('setobjectmaterial'), Array, Nothing),
    BinaryExpression(Object, Keyword('setobjectmaterialglobal'), Array, Nothing),
    BinaryExpression(Control, Keyword('setobjectproxy'), Array, Anything),
    BinaryExpression(Object, Keyword('setobjecttexture'), Array, Nothing),
    BinaryExpression(Object, Keyword('setobjecttextureglobal'), Array, Nothing),
    BinaryExpression(Number, Keyword('setovercast'), Number, Nothing),
    BinaryExpression(Object, Keyword('setowner'), Number, Boolean),
    BinaryExpression(Object, Keyword('setoxygenremaining'), Number, Nothing),
    BinaryExpression(Object, Keyword('setparticlecircle'), Array, Nothing),
    BinaryExpression(Object, Keyword('setparticleclass'), String, Nothing),
    BinaryExpression(Object, Keyword('setparticlefire'), Array, Nothing),
    BinaryExpression(Object, Keyword('setparticleparams'), Array, Nothing),
    BinaryExpression(Object, Keyword('setparticlerandom'), Array, Nothing),
    BinaryExpression(Object, Keyword('setpilotcameradirection'), Array, Nothing),
    BinaryExpression(Object, Keyword('setpilotcamerarotation'), Array, Nothing),
    BinaryExpression(Object, Keyword('setpilotcameratarget'), Object, Boolean),
    BinaryExpression(Object, Keyword('setpilotcameratarget'), Array, Boolean),
    BinaryExpression(Object, Keyword('setpilotlight'), Boolean, Nothing),
    BinaryExpression(String, Keyword('setpipeffect'), Array, Nothing),
    BinaryExpression(Object, Keyword('setpitch'), Number, Nothing),
    BinaryExpression(Object, Keyword('setpos'), Array, Nothing),
    BinaryExpression(Object, Keyword('setposasl'), Array, Nothing),
    BinaryExpression(Object, Keyword('setposasl2'), Array, Nothing),
    BinaryExpression(Object, Keyword('setposaslw'), Array, Nothing),
    BinaryExpression(Object, Keyword('setposatl'), Array, Nothing),
    BinaryExpression(Location, Keyword('setposition'), Array, Nothing),
    BinaryExpression(Object, Keyword('setposworld'), Array, Nothing),
    BinaryExpression(Object, Keyword('setpylonloadout'), Array, Boolean),
    BinaryExpression(Object, Keyword('setpylonspriority'), Array, Nothing),
    BinaryExpression(Number, Keyword('setradiomsg'), String, Nothing),
    BinaryExpression(Number, Keyword('setrain'), Number, Nothing),
    BinaryExpression(Number, Keyword('setrainbow'), Number, Nothing),
    BinaryExpression(Object, Keyword('setrandomlip'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setrank'), String, Nothing),
    BinaryExpression(Location, Keyword('setrectangular'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setrepaircargo'), Number, Nothing),
    BinaryExpression(Object, Keyword('setrotorbrakertd'), Number, Nothing),
    BinaryExpression(Object, Keyword('setshotparents'), Array, Nothing),
    BinaryExpression(Location, Keyword('setside'), Side, Nothing),
    BinaryExpression(Task, Keyword('setsimpletaskalwaysvisible'), Boolean, Nothing),
    BinaryExpression(Task, Keyword('setsimpletaskcustomdata'), Array, Nothing),
    BinaryExpression(Task, Keyword('setsimpletaskdescription'), Array, Nothing),
    BinaryExpression(Task, Keyword('setsimpletaskdestination'), Array, Nothing),
    BinaryExpression(Task, Keyword('setsimpletasktarget'), Array, Nothing),
    BinaryExpression(Task, Keyword('setsimpletasktype'), String, Nothing),
    BinaryExpression(Location, Keyword('setsize'), Array, Nothing),
    BinaryExpression(Object, Keyword('setskill'), Array, Nothing),
    BinaryExpression(Object, Keyword('setskill'), Number, Nothing),
    BinaryExpression(Object, Keyword('setslingload'), Object, Boolean),
    BinaryExpression(Object, Keyword('setsoundeffect'), Array, Nothing),
    BinaryExpression(Array, Keyword('setsoundeffect'), Array, Nothing),
    BinaryExpression(Object, Keyword('setspeaker'), String, Nothing),
    BinaryExpression(Location, Keyword('setspeech'), String, Nothing),
    BinaryExpression(Object, Keyword('setspeedmode'), String, Nothing),
    BinaryExpression(Group, Keyword('setspeedmode'), String, Nothing),
    BinaryExpression(Object, Keyword('setstamina'), Number, Nothing),
    BinaryExpression(Object, Keyword('setsuppression'), Number, Nothing),
    BinaryExpression(Object, Keyword('settargetage'), String, Nothing),
    BinaryExpression(Object, Keyword('settaskmarkeroffset'), Array, Nothing),
    BinaryExpression(Task, Keyword('settaskresult'), Array, Nothing),
    BinaryExpression(Task, Keyword('settaskstate'), String, Nothing),
    BinaryExpression(Location, Keyword('settext'), String, Nothing),
    BinaryExpression(Object, Keyword('settitleeffect'), Array, Nothing),
    BinaryExpression(Array, Keyword('settitleeffect'), Array, Nothing),
    BinaryExpression(Object, Keyword('settriggeractivation'), Array, Nothing),
    BinaryExpression(Object, Keyword('settriggerarea'), Array, Nothing),
    BinaryExpression(Object, Keyword('settriggerstatements'), Array, Nothing),
    BinaryExpression(Object, Keyword('settriggertext'), String, Nothing),
    BinaryExpression(Object, Keyword('settriggertimeout'), Array, Nothing),
    BinaryExpression(Object, Keyword('settriggertype'), String, Nothing),
    BinaryExpression(Location, Keyword('settype'), String, Nothing),
    BinaryExpression(Object, Keyword('setunconscious'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setunitability'), Number, Nothing),
    BinaryExpression(Object, Keyword('setunitloadout'), Array, Nothing),
    BinaryExpression(Object, Keyword('setunitloadout'), String, Nothing),
    BinaryExpression(Object, Keyword('setunitloadout'), Config, Nothing),
    BinaryExpression(Object, Keyword('setunitpos'), String, Nothing),
    BinaryExpression(Object, Keyword('setunitposweak'), String, Nothing),
    BinaryExpression(Object, Keyword('setunitrank'), String, Nothing),
    BinaryExpression(Object, Keyword('setunitrecoilcoefficient'), Number, Nothing),
    BinaryExpression(Object, Keyword('setunittrait'), Array, Nothing),
    BinaryExpression(Object, Keyword('setunloadincombat'), Array, Nothing),
    BinaryExpression(Object, Keyword('setuseractiontext'), Array, Nothing),
    BinaryExpression(Object, Keyword('setusermfdvalue'), Array, Nothing),
    BinaryExpression(Display, Keyword('setvariable'), Array, Nothing),
    BinaryExpression(Control, Keyword('setvariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setvariable'), Array, Nothing),
    BinaryExpression(Group, Keyword('setvariable'), Array, Nothing),
    BinaryExpression(Namespace, Keyword('setvariable'), Array, Nothing),
    BinaryExpression(TeamMember, Keyword('setvariable'), Array, Nothing),
    BinaryExpression(Task, Keyword('setvariable'), Array, Nothing),
    BinaryExpression(Location, Keyword('setvariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setvectordir'), Array, Nothing),
    BinaryExpression(Object, Keyword('setvectordirandup'), Array, Nothing),
    BinaryExpression(Object, Keyword('setvectorup'), Array, Nothing),
    BinaryExpression(Object, Keyword('setvehicleammo'), Number, Nothing),
    BinaryExpression(Object, Keyword('setvehicleammodef'), Number, Nothing),
    BinaryExpression(Object, Keyword('setvehiclearmor'), Number, Nothing),
    BinaryExpression(Object, Keyword('setvehiclecargo'), Object, Boolean),
    BinaryExpression(Object, Keyword('setvehicleid'), Number, Nothing),
    BinaryExpression(Object, Keyword('setvehiclelock'), String, Nothing),
    BinaryExpression(Object, Keyword('setvehicleposition'), Array, Boolean),
    BinaryExpression(Object, Keyword('setvehicleradar'), Number, Nothing),
    BinaryExpression(Object, Keyword('setvehiclereceiveremotetargets'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setvehiclereportownposition'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setvehiclereportremotetargets'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setvehicletipars'), Array, Nothing),
    BinaryExpression(Object, Keyword('setvehiclevarname'), String, Nothing),
    BinaryExpression(Object, Keyword('setvelocity'), Array, Nothing),
    BinaryExpression(Object, Keyword('setvelocitymodelspace'), Array, Nothing),
    BinaryExpression(Object, Keyword('setvelocitytransformation'), Array, Nothing),
    BinaryExpression(Control, Keyword('setvisibleiftreecollapsed'), Array, Nothing),
    BinaryExpression(Object, Keyword('setwantedrpmrtd'), Array, Nothing),
    BinaryExpression(Number, Keyword('setwaves'), Number, Nothing),
    BinaryExpression(Array, Keyword('setwaypointbehaviour'), String, Nothing),
    BinaryExpression(Array, Keyword('setwaypointcombatmode'), String, Nothing),
    BinaryExpression(Array, Keyword('setwaypointcompletionradius'), Number, Nothing),
    BinaryExpression(Array, Keyword('setwaypointdescription'), String, Nothing),
    BinaryExpression(Array, Keyword('setwaypointforcebehaviour'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('setwaypointformation'), String, Nothing),
    BinaryExpression(Array, Keyword('setwaypointhouseposition'), Number, Nothing),
    BinaryExpression(Array, Keyword('setwaypointloiterradius'), Number, Nothing),
    BinaryExpression(Array, Keyword('setwaypointloitertype'), String, Nothing),
    BinaryExpression(Array, Keyword('setwaypointname'), String, Nothing),
    BinaryExpression(Array, Keyword('setwaypointposition'), Array, Nothing),
    BinaryExpression(Array, Keyword('setwaypointscript'), String, Nothing),
    BinaryExpression(Array, Keyword('setwaypointspeed'), String, Nothing),
    BinaryExpression(Array, Keyword('setwaypointstatements'), Array, Nothing),
    BinaryExpression(Array, Keyword('setwaypointtimeout'), Array, Nothing),
    BinaryExpression(Array, Keyword('setwaypointtype'), String, Nothing),
    BinaryExpression(Array, Keyword('setwaypointvisible'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setweaponreloadingtime'), Array, Boolean),
    BinaryExpression(Number, Keyword('setwinddir'), Number, Nothing),
    BinaryExpression(Number, Keyword('setwindforce'), Number, Nothing),
    BinaryExpression(Number, Keyword('setwindstr'), Number, Nothing),
    BinaryExpression(Object, Keyword('setwingforcescalertd'), Array, Nothing),
    BinaryExpression(Array, Keyword('setwppos'), Array, Nothing),
    BinaryExpression(Control, Keyword('show3dicons'), Boolean, Nothing),
    BinaryExpression(Control, Keyword('showlegend'), Boolean, Nothing),
    BinaryExpression(Control, Keyword('showneweditorobject'), Array, Anything),
    BinaryExpression(Array, Keyword('showwaypoint'), String, Nothing),
    BinaryExpression(Object, Keyword('sidechat'), String, Nothing),
    BinaryExpression(Array, Keyword('sidechat'), String, Nothing),
    BinaryExpression(Object, Keyword('sideradio'), String, Nothing),
    BinaryExpression(Array, Keyword('sideradio'), String, Nothing),
    BinaryExpression(Object, Keyword('skill'), String, Number),
    BinaryExpression(Object, Keyword('skillfinal'), String, Number),
    BinaryExpression(Control, Keyword('slidersetposition'), Number, Nothing),
    BinaryExpression(Control, Keyword('slidersetrange'), Array, Nothing),
    BinaryExpression(Control, Keyword('slidersetspeed'), Array, Nothing),
    BinaryExpression(Array, Keyword('sort'), Boolean, Nothing),
    BinaryExpression(Type, Keyword('spawn'), Code, Script),
    BinaryExpression(String, Keyword('splitstring'), String, Array),
    BinaryExpression(ForType, Keyword('step'), Number, ForType),
    BinaryExpression(Object, Keyword('stop'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('suppressfor'), Number, Nothing),
    BinaryExpression(Object, Keyword('swimindepth'), Number, Nothing),
    BinaryExpression(Object, Keyword('switchaction'), String, Nothing),
    BinaryExpression(Object, Keyword('switchcamera'), String, Nothing),
    BinaryExpression(Object, Keyword('switchgesture'), String, Nothing),
    BinaryExpression(Object, Keyword('switchlight'), String, Nothing),
    BinaryExpression(Object, Keyword('switchmove'), String, Nothing),
    BinaryExpression(Object, Keyword('synchronizeobjectsadd'), Array, Nothing),
    BinaryExpression(Object, Keyword('synchronizeobjectsremove'), Array, Nothing),
    BinaryExpression(Object, Keyword('synchronizetrigger'), Array, Nothing),
    BinaryExpression(Array, Keyword('synchronizewaypoint'), Array, Nothing),
    BinaryExpression(Object, Keyword('synchronizewaypoint'), Array, Nothing),
    BinaryExpression(Object, Keyword('targetknowledge'), Object, Array),
    BinaryExpression(Object, Keyword('targets'), Array, Array),
    BinaryExpression(Array, Keyword('targetsaggregate'), Array, Array),
    BinaryExpression(Object, Keyword('targetsquery'), Array, Array),
    BinaryExpression(IfType, Keyword('then'), Code, Anything),
    BinaryExpression(IfType, Keyword('then'), Array, Anything),
    BinaryExpression(IfType, Keyword('throw'), Type, Nothing),
    BinaryExpression(ForType, Keyword('to'), Number, ForType),
    BinaryExpression(Number, Keyword('tofixed'), Number, String),
    BinaryExpression(Object, Keyword('triggerattachobject'), Number, Nothing),
    BinaryExpression(Object, Keyword('triggerattachvehicle'), Array, Nothing),
    BinaryExpression(Object, Keyword('triggerdynamicsimulation'), Boolean, Nothing),
    BinaryExpression(Type, Keyword('try'), Code, TryType),
    BinaryExpression(Object, Keyword('turretlocal'), Array, Boolean),
    BinaryExpression(Object, Keyword('turretowner'), Array, Number),
    BinaryExpression(Object, Keyword('turretunit'), Array, Object),
    BinaryExpression(Control, Keyword('tvadd'), Array, Number),
    BinaryExpression(Control, Keyword('tvcollapse'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvcount'), Array, Number),
    BinaryExpression(Control, Keyword('tvdata'), Array, String),
    BinaryExpression(Control, Keyword('tvdelete'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvexpand'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvpicture'), Array, String),
    BinaryExpression(Control, Keyword('tvpictureright'), Array, String),
    BinaryExpression(Control, Keyword('tvsetcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetcursel'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetdata'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetpicture'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetpicturecolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetpicturecolordisabled'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetpicturecolorselected'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetpictureright'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetpicturerightcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetpicturerightcolordisabled'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetpicturerightcolorselected'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetselectcolor'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsettext'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsettooltip'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsetvalue'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsort'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvsortbyvalue'), Array, Nothing),
    BinaryExpression(Control, Keyword('tvtext'), Array, String),
    BinaryExpression(Control, Keyword('tvtooltip'), Array, String),
    BinaryExpression(Control, Keyword('tvvalue'), Array, Number),
    BinaryExpression(Object, Keyword('unassignitem'), String, Nothing),
    BinaryExpression(Group, Keyword('unitsbelowheight'), Number, Array),
    BinaryExpression(Array, Keyword('unitsbelowheight'), Number, Array),
    BinaryExpression(Object, Keyword('unlinkitem'), String, Nothing),
    BinaryExpression(TeamMember, Keyword('unregistertask'), String, Boolean),
    BinaryExpression(Control, Keyword('updatedrawicon'), Array, Nothing),
    BinaryExpression(Control, Keyword('updatemenuitem'), Array, Nothing),
    BinaryExpression(Object, Keyword('useaudiotimeformoves'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('vectoradd'), Array, Array),
    BinaryExpression(Array, Keyword('vectorcos'), Array, Number),
    BinaryExpression(Array, Keyword('vectorcrossproduct'), Array, Array),
    BinaryExpression(Array, Keyword('vectordiff'), Array, Array),
    BinaryExpression(Array, Keyword('vectordistance'), Array, Number),
    BinaryExpression(Array, Keyword('vectordistancesqr'), Array, Number),
    BinaryExpression(Array, Keyword('vectordotproduct'), Array, Number),
    BinaryExpression(Array, Keyword('vectorfromto'), Array, Array),
    BinaryExpression(Object, Keyword('vectormodeltoworld'), Array, Array),
    BinaryExpression(Object, Keyword('vectormodeltoworldvisual'), Array, Array),
    BinaryExpression(Array, Keyword('vectormultiply'), Number, Array),
    BinaryExpression(Object, Keyword('vectorworldtomodel'), Array, Array),
    BinaryExpression(Object, Keyword('vectorworldtomodelvisual'), Array, Array),
    BinaryExpression(Object, Keyword('vehiclechat'), String, Nothing),
    BinaryExpression(Object, Keyword('vehicleradio'), String, Nothing),
    BinaryExpression(Array, Keyword('waypointattachobject'), Object, Nothing),
    BinaryExpression(Array, Keyword('waypointattachobject'), Number, Nothing),
    BinaryExpression(Array, Keyword('waypointattachvehicle'), Object, Nothing),
    BinaryExpression(Object, Keyword('weaponaccessories'), String, Array),
    BinaryExpression(Object, Keyword('weaponaccessoriescargo'), Array, Array),
    BinaryExpression(Object, Keyword('weapondirection'), String, Array),
    BinaryExpression(Object, Keyword('weaponsturret'), Array, Array),
    BinaryExpression(Object, Keyword('worldtomodel'), Array, Array),
    BinaryExpression(Object, Keyword('worldtomodelvisual'), Array, Array),
    NullExpression(Keyword('acctime'), Number),
    NullExpression(Keyword('activatedaddons'), Array),
    NullExpression(Keyword('agents'), Array),
    NullExpression(Keyword('airdensitycurvertd'), Array),
    NullExpression(Keyword('all3denentities'), Array),
    NullExpression(Keyword('allairports'), Array),
    NullExpression(Keyword('allcurators'), Array),
    NullExpression(Keyword('allcutlayers'), Array),
    NullExpression(Keyword('alldead'), Array),
    NullExpression(Keyword('alldeadmen'), Array),
    NullExpression(Keyword('alldisplays'), Array),
    NullExpression(Keyword('allgroups'), Array),
    NullExpression(Keyword('allmapmarkers'), Array),
    NullExpression(Keyword('allmines'), Array),
    NullExpression(Keyword('allplayers'), Array),
    NullExpression(Keyword('allsites'), Array),
    NullExpression(Keyword('allunits'), Array),
    NullExpression(Keyword('allunitsuav'), Array),
    NullExpression(Keyword('armorypoints'), Number),
    NullExpression(Keyword('benchmark'), Number),
    NullExpression(Keyword('blufor'), Side),
    NullExpression(Keyword('briefingname'), String),
    NullExpression(Keyword('buldozer_isenabledroaddiag'), Boolean),
    NullExpression(Keyword('buldozer_reloadopermap'), Nothing),
    NullExpression(Keyword('cadetmode'), Boolean),
    NullExpression(Keyword('cameraon'), Object),
    NullExpression(Keyword('cameraview'), String),
    NullExpression(Keyword('campaignconfigfile'), Config),
    NullExpression(Keyword('cansuspend'), Boolean),
    NullExpression(Keyword('cheatsenabled'), Boolean),
    NullExpression(Keyword('civilian'), Side),
    NullExpression(Keyword('clearforcesrtd'), Nothing),
    NullExpression(Keyword('clearitempool'), Nothing),
    NullExpression(Keyword('clearmagazinepool'), Nothing),
    NullExpression(Keyword('clearradio'), Nothing),
    NullExpression(Keyword('clearweaponpool'), Nothing),
    NullExpression(Keyword('clientowner'), Number),
    NullExpression(Keyword('commandingmenu'), String),
    NullExpression(Keyword('configfile'), Config),
    NullExpression(Keyword('confignull'), Config),
    NullExpression(Keyword('controlnull'), Control),
    NullExpression(Keyword('copyfromclipboard'), String),
    NullExpression(Keyword('curatorcamera'), Object),
    NullExpression(Keyword('curatormouseover'), Object),
    NullExpression(Keyword('curatorselected'), Array),
    NullExpression(Keyword('current3denoperation'), String),
    NullExpression(Keyword('currentchannel'), Number),
    NullExpression(Keyword('currentnamespace'), Namespace, action=lambda i: 'missionNamespace'),
    NullExpression(Keyword('cursorobject'), Object),
    NullExpression(Keyword('cursortarget'), Object),
    NullExpression(Keyword('date'), Array),
    NullExpression(Keyword('daytime'), Number),
    NullExpression(Keyword('diag_activemissionfsms'), Array),
    NullExpression(Keyword('diag_activescripts'), Array),
    NullExpression(Keyword('diag_activesqfscripts'), Array),
    NullExpression(Keyword('diag_activesqsscripts'), Array),
    NullExpression(Keyword('diag_fps'), Number),
    NullExpression(Keyword('diag_fpsmin'), Number),
    NullExpression(Keyword('diag_frameno'), Number),
    NullExpression(Keyword('diag_ticktime'), Number),
    NullExpression(Keyword('dialog'), Boolean),
    NullExpression(Keyword('didjip'), Boolean),
    NullExpression(Keyword('difficulty'), Number),
    NullExpression(Keyword('difficultyenabledrtd'), Boolean),
    NullExpression(Keyword('disabledebriefingstats'), Nothing),
    NullExpression(Keyword('disableserialization'), Nothing),
    NullExpression(Keyword('displaynull'), Display),
    NullExpression(Keyword('distributionregion'), Number),
    NullExpression(Keyword('dynamicsimulationsystemenabled'), Boolean),
    NullExpression(Keyword('east'), Side),
    NullExpression(Keyword('enableenddialog'), Nothing),
    NullExpression(Keyword('endl'), String),
    NullExpression(Keyword('endloadingscreen'), Nothing),
    NullExpression(Keyword('environmentenabled'), Array),
    NullExpression(Keyword('estimatedendservertime'), Number),
    NullExpression(Keyword('exit'), Nothing),
    NullExpression(Keyword('false'), Boolean),
    NullExpression(Keyword('finishmissioninit'), Nothing),
    NullExpression(Keyword('fog'), Number),
    NullExpression(Keyword('fogforecast'), Number),
    NullExpression(Keyword('fogparams'), Array),
    NullExpression(Keyword('forcedmap'), Array),
    NullExpression(Keyword('forceend'), Nothing),
    NullExpression(Keyword('forceweatherchange'), Nothing),
    NullExpression(Keyword('freelook'), Boolean),
    NullExpression(Keyword('get3dencamera'), Object),
    NullExpression(Keyword('get3deniconsvisible'), Array),
    NullExpression(Keyword('get3denlinesvisible'), Array),
    NullExpression(Keyword('get3denmouseover'), Array),
    NullExpression(Keyword('getartillerycomputersettings'), Array),
    NullExpression(Keyword('getclientstate'), String),
    NullExpression(Keyword('getclientstatenumber'), Number),
    NullExpression(Keyword('getcursorobjectparams'), Array),
    NullExpression(Keyword('getdlcassetsusage'), Array),
    NullExpression(Keyword('getelevationoffset'), Number),
    NullExpression(Keyword('getmissiondlcs'), Array),
    NullExpression(Keyword('getmissionlayers'), Array),
    NullExpression(Keyword('getmouseposition'), Array),
    NullExpression(Keyword('getobjectviewdistance'), Array),
    NullExpression(Keyword('getremotesensorsdisabled'), Boolean),
    NullExpression(Keyword('getresolution'), Array),
    NullExpression(Keyword('getshadowdistance'), Number),
    NullExpression(Keyword('getterraingrid'), Number),
    NullExpression(Keyword('gettotaldlcusagetime'), Number),
    NullExpression(Keyword('groupiconselectable'), Boolean),
    NullExpression(Keyword('groupiconsvisible'), Array),
    NullExpression(Keyword('grpnull'), Group),
    NullExpression(Keyword('gusts'), Number),
    NullExpression(Keyword('halt'), Nothing),
    NullExpression(Keyword('hasinterface'), Boolean),
    NullExpression(Keyword('hcshownbar'), Boolean),
    NullExpression(Keyword('hudmovementlevels'), Array),
    NullExpression(Keyword('humidity'), Number),
    NullExpression(Keyword('independent'), Side),
    NullExpression(Keyword('initambientlife'), Nothing),
    NullExpression(Keyword('is3den'), Boolean),
    NullExpression(Keyword('is3denmultiplayer'), Boolean),
    NullExpression(Keyword('isautotest'), Boolean),
    NullExpression(Keyword('isdedicated'), Boolean),
    NullExpression(Keyword('isfilepatchingenabled'), Boolean),
    NullExpression(Keyword('isinstructorfigureenabled'), Boolean),
    NullExpression(Keyword('ismultiplayer'), Boolean),
    NullExpression(Keyword('ismultiplayersolo'), Boolean),
    NullExpression(Keyword('ispipenabled'), Boolean),
    NullExpression(Keyword('isremoteexecuted'), Boolean),
    NullExpression(Keyword('isremoteexecutedjip'), Boolean),
    NullExpression(Keyword('isserver'), Boolean),
    NullExpression(Keyword('issteammission'), Boolean),
    NullExpression(Keyword('isstreamfriendlyuienabled'), Boolean),
    NullExpression(Keyword('isstressdamageenabled'), Boolean),
    NullExpression(Keyword('istuthintsenabled'), Boolean),
    NullExpression(Keyword('isuicontext'), Boolean),
    NullExpression(Keyword('language'), String),
    NullExpression(Keyword('librarycredits'), Array),
    NullExpression(Keyword('librarydisclaimers'), Array),
    NullExpression(Keyword('lightnings'), Number),
    NullExpression(Keyword('linebreak'), String),
    NullExpression(Keyword('loadgame'), Nothing),
    NullExpression(Keyword('locationnull'), Location),
    NullExpression(Keyword('logentities'), Nothing),
    NullExpression(Keyword('mapanimclear'), Nothing),
    NullExpression(Keyword('mapanimcommit'), Nothing),
    NullExpression(Keyword('mapanimdone'), Boolean),
    NullExpression(Keyword('markasfinishedonsteam'), Boolean),
    NullExpression(Keyword('missionconfigfile'), Config),
    NullExpression(Keyword('missiondifficulty'), Number),
    NullExpression(Keyword('missionname'), String),
    NullExpression(Keyword('missionnamespace'), Namespace, action=lambda i: 'missionNamespace'),
    NullExpression(Keyword('missionstart'), Array),
    NullExpression(Keyword('missionversion'), Number),
    NullExpression(Keyword('moonintensity'), Number),
    NullExpression(Keyword('musicvolume'), Number),
    NullExpression(Keyword('netobjnull'), NetObject),
    NullExpression(Keyword('nextweatherchange'), Number),
    NullExpression(Keyword('nil'), Anything),
    NullExpression(Keyword('objnull'), Object),
    NullExpression(Keyword('opencuratorinterface'), Nothing),
    NullExpression(Keyword('opfor'), Side),
    NullExpression(Keyword('overcast'), Number),
    NullExpression(Keyword('overcastforecast'), Number),
    NullExpression(Keyword('parsingnamespace'), Namespace, action=lambda i: 'missionNamespace'),
    NullExpression(Keyword('particlesquality'), Number),
    NullExpression(Keyword('pi'), Number),
    NullExpression(Keyword('pixelgrid'), Number),
    NullExpression(Keyword('pixelgridbase'), Number),
    NullExpression(Keyword('pixelgridnouiscale'), Number),
    NullExpression(Keyword('pixelh'), Number),
    NullExpression(Keyword('pixelw'), Number),
    NullExpression(Keyword('playableunits'), Array),
    NullExpression(Keyword('player'), Object),
    NullExpression(Keyword('playerrespawntime'), Number),
    NullExpression(Keyword('playerside'), Side),
    NullExpression(Keyword('productversion'), Array),
    NullExpression(Keyword('profilename'), String),
    NullExpression(Keyword('profilenamespace'), Namespace, action=lambda i: 'missionNamespace'),
    NullExpression(Keyword('profilenamesteam'), String),
    NullExpression(Keyword('radiovolume'), Number),
    NullExpression(Keyword('rain'), Number),
    NullExpression(Keyword('rainbow'), Number),
    NullExpression(Keyword('remoteexecutedowner'), Number),
    NullExpression(Keyword('resetcamshake'), Nothing),
    NullExpression(Keyword('resistance'), Side),
    NullExpression(Keyword('reversedmousey'), Boolean),
    NullExpression(Keyword('runinitscript'), Nothing),
    NullExpression(Keyword('safezoneh'), Number),
    NullExpression(Keyword('safezonew'), Number),
    NullExpression(Keyword('safezonewabs'), Number),
    NullExpression(Keyword('safezonex'), Number),
    NullExpression(Keyword('safezonexabs'), Number),
    NullExpression(Keyword('safezoney'), Number),
    NullExpression(Keyword('savegame'), Nothing),
    NullExpression(Keyword('savejoysticks'), Nothing),
    NullExpression(Keyword('saveprofilenamespace'), Nothing),
    NullExpression(Keyword('savingenabled'), Boolean),
    NullExpression(Keyword('scriptnull'), Script),
    NullExpression(Keyword('selectnoplayer'), Nothing),
    NullExpression(Keyword('servername'), String),
    NullExpression(Keyword('servertime'), Number),
    NullExpression(Keyword('shownartillerycomputer'), Boolean),
    NullExpression(Keyword('shownchat'), Boolean),
    NullExpression(Keyword('showncompass'), Boolean),
    NullExpression(Keyword('showncuratorcompass'), Boolean),
    NullExpression(Keyword('showngps'), Boolean),
    NullExpression(Keyword('shownhud'), Array),
    NullExpression(Keyword('shownmap'), Boolean),
    NullExpression(Keyword('shownpad'), Boolean),
    NullExpression(Keyword('shownradio'), Boolean),
    NullExpression(Keyword('shownscoretable'), Number),
    NullExpression(Keyword('shownuavfeed'), Boolean),
    NullExpression(Keyword('shownwarrant'), Boolean),
    NullExpression(Keyword('shownwatch'), Boolean),
    NullExpression(Keyword('sideambientlife'), Side),
    NullExpression(Keyword('sideempty'), Side),
    NullExpression(Keyword('sideenemy'), Side),
    NullExpression(Keyword('sidefriendly'), Side),
    NullExpression(Keyword('sidelogic'), Side),
    NullExpression(Keyword('sideunknown'), Side),
    NullExpression(Keyword('simulweathersync'), Nothing),
    NullExpression(Keyword('slingloadassistantshown'), Boolean),
    NullExpression(Keyword('soundvolume'), Number),
    NullExpression(Keyword('sunormoon'), Number),
    NullExpression(Keyword('switchableunits'), Array),
    NullExpression(Keyword('systemofunits'), Number),
    NullExpression(Keyword('tasknull'), Task),
    NullExpression(Keyword('teammembernull'), TeamMember),
    NullExpression(Keyword('teams'), Array),
    NullExpression(Keyword('teamswitch'), Nothing),
    NullExpression(Keyword('teamswitchenabled'), Boolean),
    NullExpression(Keyword('time'), Number),
    NullExpression(Keyword('timemultiplier'), Number),
    NullExpression(Keyword('true'), Boolean),
    NullExpression(Keyword('uinamespace'), Namespace, action=lambda i: 'missionNamespace'),
    NullExpression(Keyword('userinputdisabled'), Boolean),
    NullExpression(Keyword('vehicles'), Array),
    NullExpression(Keyword('viewdistance'), Number),
    NullExpression(Keyword('visiblecompass'), Boolean),
    NullExpression(Keyword('visiblegps'), Boolean),
    NullExpression(Keyword('visiblemap'), Boolean),
    NullExpression(Keyword('visiblescoretable'), Boolean),
    NullExpression(Keyword('visiblewatch'), Boolean),
    NullExpression(Keyword('waves'), Number),
    NullExpression(Keyword('west'), Side),
    NullExpression(Keyword('wind'), Array),
    NullExpression(Keyword('winddir'), Number),
    NullExpression(Keyword('windrtd'), Array),
    NullExpression(Keyword('windstr'), Number),
    NullExpression(Keyword('worldname'), String),
    NullExpression(Keyword('worldsize'), Number)
]
